from enum import Enum
import math
import string


class ThermalResistanceUnits(Enum):
        """
            ThermalResistanceUnits enumeration
        """
        
        SquareMeterKelvinPerKilowatt = 'square_meter_kelvin_per_kilowatt'
        """
            
        """
        
        SquareMeterKelvinPerWatt = 'square_meter_kelvin_per_watt'
        """
            
        """
        
        SquareMeterDegreeCelsiusPerWatt = 'square_meter_degree_celsius_per_watt'
        """
            
        """
        
        SquareCentimeterKelvinPerWatt = 'square_centimeter_kelvin_per_watt'
        """
            
        """
        
        SquareCentimeterHourDegreeCelsiusPerKilocalorie = 'square_centimeter_hour_degree_celsius_per_kilocalorie'
        """
            
        """
        
        HourSquareFeetDegreeFahrenheitPerBtu = 'hour_square_feet_degree_fahrenheit_per_btu'
        """
            
        """
        

class ThermalResistance:
    """
    Heat Transfer Coefficient or Thermal conductivity - indicates a materials ability to conduct heat.

    Args:
        value (float): The value.
        from_unit (ThermalResistanceUnits): The ThermalResistance unit to create from, The default unit is SquareMeterKelvinPerKilowatt
    """
    def __init__(self, value: float, from_unit: ThermalResistanceUnits = ThermalResistanceUnits.SquareMeterKelvinPerKilowatt):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__square_meter_kelvins_per_kilowatt = None
        
        self.__square_meter_kelvins_per_watt = None
        
        self.__square_meter_degrees_celsius_per_watt = None
        
        self.__square_centimeter_kelvins_per_watt = None
        
        self.__square_centimeter_hour_degrees_celsius_per_kilocalorie = None
        
        self.__hour_square_feet_degrees_fahrenheit_per_btu = None
        

    def __convert_from_base(self, from_unit: ThermalResistanceUnits) -> float:
        value = self.__value
        
        if from_unit == ThermalResistanceUnits.SquareMeterKelvinPerKilowatt:
            return (value)
        
        if from_unit == ThermalResistanceUnits.SquareMeterKelvinPerWatt:
            return (value / 1000)
        
        if from_unit == ThermalResistanceUnits.SquareMeterDegreeCelsiusPerWatt:
            return (value / 1000.0)
        
        if from_unit == ThermalResistanceUnits.SquareCentimeterKelvinPerWatt:
            return (value / 0.1)
        
        if from_unit == ThermalResistanceUnits.SquareCentimeterHourDegreeCelsiusPerKilocalorie:
            return (value / 0.0859779507590433)
        
        if from_unit == ThermalResistanceUnits.HourSquareFeetDegreeFahrenheitPerBtu:
            return (value / 176.1121482159839)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ThermalResistanceUnits) -> float:
        
        if to_unit == ThermalResistanceUnits.SquareMeterKelvinPerKilowatt:
            return (value)
        
        if to_unit == ThermalResistanceUnits.SquareMeterKelvinPerWatt:
            return (value * 1000)
        
        if to_unit == ThermalResistanceUnits.SquareMeterDegreeCelsiusPerWatt:
            return (value * 1000.0)
        
        if to_unit == ThermalResistanceUnits.SquareCentimeterKelvinPerWatt:
            return (value * 0.1)
        
        if to_unit == ThermalResistanceUnits.SquareCentimeterHourDegreeCelsiusPerKilocalorie:
            return (value * 0.0859779507590433)
        
        if to_unit == ThermalResistanceUnits.HourSquareFeetDegreeFahrenheitPerBtu:
            return (value * 176.1121482159839)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_square_meter_kelvins_per_kilowatt(square_meter_kelvins_per_kilowatt: float):
        """
        Create a new instance of ThermalResistance from a value in square_meter_kelvins_per_kilowatt.

        

        :param meters: The ThermalResistance value in square_meter_kelvins_per_kilowatt.
        :type square_meter_kelvins_per_kilowatt: float
        :return: A new instance of ThermalResistance.
        :rtype: ThermalResistance
        """
        return ThermalResistance(square_meter_kelvins_per_kilowatt, ThermalResistanceUnits.SquareMeterKelvinPerKilowatt)

    
    @staticmethod
    def from_square_meter_kelvins_per_watt(square_meter_kelvins_per_watt: float):
        """
        Create a new instance of ThermalResistance from a value in square_meter_kelvins_per_watt.

        

        :param meters: The ThermalResistance value in square_meter_kelvins_per_watt.
        :type square_meter_kelvins_per_watt: float
        :return: A new instance of ThermalResistance.
        :rtype: ThermalResistance
        """
        return ThermalResistance(square_meter_kelvins_per_watt, ThermalResistanceUnits.SquareMeterKelvinPerWatt)

    
    @staticmethod
    def from_square_meter_degrees_celsius_per_watt(square_meter_degrees_celsius_per_watt: float):
        """
        Create a new instance of ThermalResistance from a value in square_meter_degrees_celsius_per_watt.

        

        :param meters: The ThermalResistance value in square_meter_degrees_celsius_per_watt.
        :type square_meter_degrees_celsius_per_watt: float
        :return: A new instance of ThermalResistance.
        :rtype: ThermalResistance
        """
        return ThermalResistance(square_meter_degrees_celsius_per_watt, ThermalResistanceUnits.SquareMeterDegreeCelsiusPerWatt)

    
    @staticmethod
    def from_square_centimeter_kelvins_per_watt(square_centimeter_kelvins_per_watt: float):
        """
        Create a new instance of ThermalResistance from a value in square_centimeter_kelvins_per_watt.

        

        :param meters: The ThermalResistance value in square_centimeter_kelvins_per_watt.
        :type square_centimeter_kelvins_per_watt: float
        :return: A new instance of ThermalResistance.
        :rtype: ThermalResistance
        """
        return ThermalResistance(square_centimeter_kelvins_per_watt, ThermalResistanceUnits.SquareCentimeterKelvinPerWatt)

    
    @staticmethod
    def from_square_centimeter_hour_degrees_celsius_per_kilocalorie(square_centimeter_hour_degrees_celsius_per_kilocalorie: float):
        """
        Create a new instance of ThermalResistance from a value in square_centimeter_hour_degrees_celsius_per_kilocalorie.

        

        :param meters: The ThermalResistance value in square_centimeter_hour_degrees_celsius_per_kilocalorie.
        :type square_centimeter_hour_degrees_celsius_per_kilocalorie: float
        :return: A new instance of ThermalResistance.
        :rtype: ThermalResistance
        """
        return ThermalResistance(square_centimeter_hour_degrees_celsius_per_kilocalorie, ThermalResistanceUnits.SquareCentimeterHourDegreeCelsiusPerKilocalorie)

    
    @staticmethod
    def from_hour_square_feet_degrees_fahrenheit_per_btu(hour_square_feet_degrees_fahrenheit_per_btu: float):
        """
        Create a new instance of ThermalResistance from a value in hour_square_feet_degrees_fahrenheit_per_btu.

        

        :param meters: The ThermalResistance value in hour_square_feet_degrees_fahrenheit_per_btu.
        :type hour_square_feet_degrees_fahrenheit_per_btu: float
        :return: A new instance of ThermalResistance.
        :rtype: ThermalResistance
        """
        return ThermalResistance(hour_square_feet_degrees_fahrenheit_per_btu, ThermalResistanceUnits.HourSquareFeetDegreeFahrenheitPerBtu)

    
    @property
    def square_meter_kelvins_per_kilowatt(self) -> float:
        """
        
        """
        if self.__square_meter_kelvins_per_kilowatt != None:
            return self.__square_meter_kelvins_per_kilowatt
        self.__square_meter_kelvins_per_kilowatt = self.__convert_from_base(ThermalResistanceUnits.SquareMeterKelvinPerKilowatt)
        return self.__square_meter_kelvins_per_kilowatt

    
    @property
    def square_meter_kelvins_per_watt(self) -> float:
        """
        
        """
        if self.__square_meter_kelvins_per_watt != None:
            return self.__square_meter_kelvins_per_watt
        self.__square_meter_kelvins_per_watt = self.__convert_from_base(ThermalResistanceUnits.SquareMeterKelvinPerWatt)
        return self.__square_meter_kelvins_per_watt

    
    @property
    def square_meter_degrees_celsius_per_watt(self) -> float:
        """
        
        """
        if self.__square_meter_degrees_celsius_per_watt != None:
            return self.__square_meter_degrees_celsius_per_watt
        self.__square_meter_degrees_celsius_per_watt = self.__convert_from_base(ThermalResistanceUnits.SquareMeterDegreeCelsiusPerWatt)
        return self.__square_meter_degrees_celsius_per_watt

    
    @property
    def square_centimeter_kelvins_per_watt(self) -> float:
        """
        
        """
        if self.__square_centimeter_kelvins_per_watt != None:
            return self.__square_centimeter_kelvins_per_watt
        self.__square_centimeter_kelvins_per_watt = self.__convert_from_base(ThermalResistanceUnits.SquareCentimeterKelvinPerWatt)
        return self.__square_centimeter_kelvins_per_watt

    
    @property
    def square_centimeter_hour_degrees_celsius_per_kilocalorie(self) -> float:
        """
        
        """
        if self.__square_centimeter_hour_degrees_celsius_per_kilocalorie != None:
            return self.__square_centimeter_hour_degrees_celsius_per_kilocalorie
        self.__square_centimeter_hour_degrees_celsius_per_kilocalorie = self.__convert_from_base(ThermalResistanceUnits.SquareCentimeterHourDegreeCelsiusPerKilocalorie)
        return self.__square_centimeter_hour_degrees_celsius_per_kilocalorie

    
    @property
    def hour_square_feet_degrees_fahrenheit_per_btu(self) -> float:
        """
        
        """
        if self.__hour_square_feet_degrees_fahrenheit_per_btu != None:
            return self.__hour_square_feet_degrees_fahrenheit_per_btu
        self.__hour_square_feet_degrees_fahrenheit_per_btu = self.__convert_from_base(ThermalResistanceUnits.HourSquareFeetDegreeFahrenheitPerBtu)
        return self.__hour_square_feet_degrees_fahrenheit_per_btu

    
    def to_string(self, unit: ThermalResistanceUnits = ThermalResistanceUnits.SquareMeterKelvinPerKilowatt) -> string:
        """
        Format the ThermalResistance to string.
        Note! the default format for ThermalResistance is SquareMeterKelvinPerKilowatt.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ThermalResistanceUnits.SquareMeterKelvinPerKilowatt:
            return f"""{self.square_meter_kelvins_per_kilowatt} m²K/kW"""
        
        if unit == ThermalResistanceUnits.SquareMeterKelvinPerWatt:
            return f"""{self.square_meter_kelvins_per_watt} m²K/W"""
        
        if unit == ThermalResistanceUnits.SquareMeterDegreeCelsiusPerWatt:
            return f"""{self.square_meter_degrees_celsius_per_watt} m²°C/W"""
        
        if unit == ThermalResistanceUnits.SquareCentimeterKelvinPerWatt:
            return f"""{self.square_centimeter_kelvins_per_watt} cm²K/W"""
        
        if unit == ThermalResistanceUnits.SquareCentimeterHourDegreeCelsiusPerKilocalorie:
            return f"""{self.square_centimeter_hour_degrees_celsius_per_kilocalorie} cm²Hr°C/kcal"""
        
        if unit == ThermalResistanceUnits.HourSquareFeetDegreeFahrenheitPerBtu:
            return f"""{self.hour_square_feet_degrees_fahrenheit_per_btu} Hrft²°F/Btu"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ThermalResistanceUnits = ThermalResistanceUnits.SquareMeterKelvinPerKilowatt) -> string:
        """
        Get ThermalResistance unit abbreviation.
        Note! the default abbreviation for ThermalResistance is SquareMeterKelvinPerKilowatt.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ThermalResistanceUnits.SquareMeterKelvinPerKilowatt:
            return """m²K/kW"""
        
        if unit_abbreviation == ThermalResistanceUnits.SquareMeterKelvinPerWatt:
            return """m²K/W"""
        
        if unit_abbreviation == ThermalResistanceUnits.SquareMeterDegreeCelsiusPerWatt:
            return """m²°C/W"""
        
        if unit_abbreviation == ThermalResistanceUnits.SquareCentimeterKelvinPerWatt:
            return """cm²K/W"""
        
        if unit_abbreviation == ThermalResistanceUnits.SquareCentimeterHourDegreeCelsiusPerKilocalorie:
            return """cm²Hr°C/kcal"""
        
        if unit_abbreviation == ThermalResistanceUnits.HourSquareFeetDegreeFahrenheitPerBtu:
            return """Hrft²°F/Btu"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ThermalResistance):
            raise TypeError("unsupported operand type(s) for +: 'ThermalResistance' and '{}'".format(type(other).__name__))
        return ThermalResistance(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ThermalResistance):
            raise TypeError("unsupported operand type(s) for *: 'ThermalResistance' and '{}'".format(type(other).__name__))
        return ThermalResistance(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ThermalResistance):
            raise TypeError("unsupported operand type(s) for -: 'ThermalResistance' and '{}'".format(type(other).__name__))
        return ThermalResistance(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ThermalResistance):
            raise TypeError("unsupported operand type(s) for /: 'ThermalResistance' and '{}'".format(type(other).__name__))
        return ThermalResistance(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ThermalResistance):
            raise TypeError("unsupported operand type(s) for %: 'ThermalResistance' and '{}'".format(type(other).__name__))
        return ThermalResistance(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ThermalResistance):
            raise TypeError("unsupported operand type(s) for **: 'ThermalResistance' and '{}'".format(type(other).__name__))
        return ThermalResistance(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ThermalResistance):
            raise TypeError("unsupported operand type(s) for ==: 'ThermalResistance' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ThermalResistance):
            raise TypeError("unsupported operand type(s) for <: 'ThermalResistance' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ThermalResistance):
            raise TypeError("unsupported operand type(s) for >: 'ThermalResistance' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ThermalResistance):
            raise TypeError("unsupported operand type(s) for <=: 'ThermalResistance' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ThermalResistance):
            raise TypeError("unsupported operand type(s) for >=: 'ThermalResistance' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ImpulseUnits(Enum):
        """
            ImpulseUnits enumeration
        """
        
        KilogramMeterPerSecond = 'kilogram_meter_per_second'
        """
            
        """
        
        NewtonSecond = 'newton_second'
        """
            
        """
        
        PoundFootPerSecond = 'pound_foot_per_second'
        """
            
        """
        
        PoundForceSecond = 'pound_force_second'
        """
            
        """
        
        SlugFootPerSecond = 'slug_foot_per_second'
        """
            
        """
        
        NanonewtonSecond = 'nanonewton_second'
        """
            
        """
        
        MicronewtonSecond = 'micronewton_second'
        """
            
        """
        
        MillinewtonSecond = 'millinewton_second'
        """
            
        """
        
        CentinewtonSecond = 'centinewton_second'
        """
            
        """
        
        DecinewtonSecond = 'decinewton_second'
        """
            
        """
        
        DecanewtonSecond = 'decanewton_second'
        """
            
        """
        
        KilonewtonSecond = 'kilonewton_second'
        """
            
        """
        
        MeganewtonSecond = 'meganewton_second'
        """
            
        """
        

class Impulse:
    """
    In classical mechanics, impulse is the integral of a force, F, over the time interval, t, for which it acts. Impulse applied to an object produces an equivalent vector change in its linear momentum, also in the resultant direction.

    Args:
        value (float): The value.
        from_unit (ImpulseUnits): The Impulse unit to create from, The default unit is NewtonSecond
    """
    def __init__(self, value: float, from_unit: ImpulseUnits = ImpulseUnits.NewtonSecond):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__kilogram_meters_per_second = None
        
        self.__newton_seconds = None
        
        self.__pound_feet_per_second = None
        
        self.__pound_force_seconds = None
        
        self.__slug_feet_per_second = None
        
        self.__nanonewton_seconds = None
        
        self.__micronewton_seconds = None
        
        self.__millinewton_seconds = None
        
        self.__centinewton_seconds = None
        
        self.__decinewton_seconds = None
        
        self.__decanewton_seconds = None
        
        self.__kilonewton_seconds = None
        
        self.__meganewton_seconds = None
        

    def __convert_from_base(self, from_unit: ImpulseUnits) -> float:
        value = self.__value
        
        if from_unit == ImpulseUnits.KilogramMeterPerSecond:
            return (value)
        
        if from_unit == ImpulseUnits.NewtonSecond:
            return (value)
        
        if from_unit == ImpulseUnits.PoundFootPerSecond:
            return (value * 7.230657989877)
        
        if from_unit == ImpulseUnits.PoundForceSecond:
            return (value * 0.2248089430997)
        
        if from_unit == ImpulseUnits.SlugFootPerSecond:
            return (value * 0.224735720691)
        
        if from_unit == ImpulseUnits.NanonewtonSecond:
            return ((value) / 1e-09)
        
        if from_unit == ImpulseUnits.MicronewtonSecond:
            return ((value) / 1e-06)
        
        if from_unit == ImpulseUnits.MillinewtonSecond:
            return ((value) / 0.001)
        
        if from_unit == ImpulseUnits.CentinewtonSecond:
            return ((value) / 0.01)
        
        if from_unit == ImpulseUnits.DecinewtonSecond:
            return ((value) / 0.1)
        
        if from_unit == ImpulseUnits.DecanewtonSecond:
            return ((value) / 10.0)
        
        if from_unit == ImpulseUnits.KilonewtonSecond:
            return ((value) / 1000.0)
        
        if from_unit == ImpulseUnits.MeganewtonSecond:
            return ((value) / 1000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ImpulseUnits) -> float:
        
        if to_unit == ImpulseUnits.KilogramMeterPerSecond:
            return (value)
        
        if to_unit == ImpulseUnits.NewtonSecond:
            return (value)
        
        if to_unit == ImpulseUnits.PoundFootPerSecond:
            return (value / 7.230657989877)
        
        if to_unit == ImpulseUnits.PoundForceSecond:
            return (value / 0.2248089430997)
        
        if to_unit == ImpulseUnits.SlugFootPerSecond:
            return (value / 0.224735720691)
        
        if to_unit == ImpulseUnits.NanonewtonSecond:
            return ((value) * 1e-09)
        
        if to_unit == ImpulseUnits.MicronewtonSecond:
            return ((value) * 1e-06)
        
        if to_unit == ImpulseUnits.MillinewtonSecond:
            return ((value) * 0.001)
        
        if to_unit == ImpulseUnits.CentinewtonSecond:
            return ((value) * 0.01)
        
        if to_unit == ImpulseUnits.DecinewtonSecond:
            return ((value) * 0.1)
        
        if to_unit == ImpulseUnits.DecanewtonSecond:
            return ((value) * 10.0)
        
        if to_unit == ImpulseUnits.KilonewtonSecond:
            return ((value) * 1000.0)
        
        if to_unit == ImpulseUnits.MeganewtonSecond:
            return ((value) * 1000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_kilogram_meters_per_second(kilogram_meters_per_second: float):
        """
        Create a new instance of Impulse from a value in kilogram_meters_per_second.

        

        :param meters: The Impulse value in kilogram_meters_per_second.
        :type kilogram_meters_per_second: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(kilogram_meters_per_second, ImpulseUnits.KilogramMeterPerSecond)

    
    @staticmethod
    def from_newton_seconds(newton_seconds: float):
        """
        Create a new instance of Impulse from a value in newton_seconds.

        

        :param meters: The Impulse value in newton_seconds.
        :type newton_seconds: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(newton_seconds, ImpulseUnits.NewtonSecond)

    
    @staticmethod
    def from_pound_feet_per_second(pound_feet_per_second: float):
        """
        Create a new instance of Impulse from a value in pound_feet_per_second.

        

        :param meters: The Impulse value in pound_feet_per_second.
        :type pound_feet_per_second: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(pound_feet_per_second, ImpulseUnits.PoundFootPerSecond)

    
    @staticmethod
    def from_pound_force_seconds(pound_force_seconds: float):
        """
        Create a new instance of Impulse from a value in pound_force_seconds.

        

        :param meters: The Impulse value in pound_force_seconds.
        :type pound_force_seconds: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(pound_force_seconds, ImpulseUnits.PoundForceSecond)

    
    @staticmethod
    def from_slug_feet_per_second(slug_feet_per_second: float):
        """
        Create a new instance of Impulse from a value in slug_feet_per_second.

        

        :param meters: The Impulse value in slug_feet_per_second.
        :type slug_feet_per_second: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(slug_feet_per_second, ImpulseUnits.SlugFootPerSecond)

    
    @staticmethod
    def from_nanonewton_seconds(nanonewton_seconds: float):
        """
        Create a new instance of Impulse from a value in nanonewton_seconds.

        

        :param meters: The Impulse value in nanonewton_seconds.
        :type nanonewton_seconds: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(nanonewton_seconds, ImpulseUnits.NanonewtonSecond)

    
    @staticmethod
    def from_micronewton_seconds(micronewton_seconds: float):
        """
        Create a new instance of Impulse from a value in micronewton_seconds.

        

        :param meters: The Impulse value in micronewton_seconds.
        :type micronewton_seconds: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(micronewton_seconds, ImpulseUnits.MicronewtonSecond)

    
    @staticmethod
    def from_millinewton_seconds(millinewton_seconds: float):
        """
        Create a new instance of Impulse from a value in millinewton_seconds.

        

        :param meters: The Impulse value in millinewton_seconds.
        :type millinewton_seconds: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(millinewton_seconds, ImpulseUnits.MillinewtonSecond)

    
    @staticmethod
    def from_centinewton_seconds(centinewton_seconds: float):
        """
        Create a new instance of Impulse from a value in centinewton_seconds.

        

        :param meters: The Impulse value in centinewton_seconds.
        :type centinewton_seconds: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(centinewton_seconds, ImpulseUnits.CentinewtonSecond)

    
    @staticmethod
    def from_decinewton_seconds(decinewton_seconds: float):
        """
        Create a new instance of Impulse from a value in decinewton_seconds.

        

        :param meters: The Impulse value in decinewton_seconds.
        :type decinewton_seconds: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(decinewton_seconds, ImpulseUnits.DecinewtonSecond)

    
    @staticmethod
    def from_decanewton_seconds(decanewton_seconds: float):
        """
        Create a new instance of Impulse from a value in decanewton_seconds.

        

        :param meters: The Impulse value in decanewton_seconds.
        :type decanewton_seconds: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(decanewton_seconds, ImpulseUnits.DecanewtonSecond)

    
    @staticmethod
    def from_kilonewton_seconds(kilonewton_seconds: float):
        """
        Create a new instance of Impulse from a value in kilonewton_seconds.

        

        :param meters: The Impulse value in kilonewton_seconds.
        :type kilonewton_seconds: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(kilonewton_seconds, ImpulseUnits.KilonewtonSecond)

    
    @staticmethod
    def from_meganewton_seconds(meganewton_seconds: float):
        """
        Create a new instance of Impulse from a value in meganewton_seconds.

        

        :param meters: The Impulse value in meganewton_seconds.
        :type meganewton_seconds: float
        :return: A new instance of Impulse.
        :rtype: Impulse
        """
        return Impulse(meganewton_seconds, ImpulseUnits.MeganewtonSecond)

    
    @property
    def kilogram_meters_per_second(self) -> float:
        """
        
        """
        if self.__kilogram_meters_per_second != None:
            return self.__kilogram_meters_per_second
        self.__kilogram_meters_per_second = self.__convert_from_base(ImpulseUnits.KilogramMeterPerSecond)
        return self.__kilogram_meters_per_second

    
    @property
    def newton_seconds(self) -> float:
        """
        
        """
        if self.__newton_seconds != None:
            return self.__newton_seconds
        self.__newton_seconds = self.__convert_from_base(ImpulseUnits.NewtonSecond)
        return self.__newton_seconds

    
    @property
    def pound_feet_per_second(self) -> float:
        """
        
        """
        if self.__pound_feet_per_second != None:
            return self.__pound_feet_per_second
        self.__pound_feet_per_second = self.__convert_from_base(ImpulseUnits.PoundFootPerSecond)
        return self.__pound_feet_per_second

    
    @property
    def pound_force_seconds(self) -> float:
        """
        
        """
        if self.__pound_force_seconds != None:
            return self.__pound_force_seconds
        self.__pound_force_seconds = self.__convert_from_base(ImpulseUnits.PoundForceSecond)
        return self.__pound_force_seconds

    
    @property
    def slug_feet_per_second(self) -> float:
        """
        
        """
        if self.__slug_feet_per_second != None:
            return self.__slug_feet_per_second
        self.__slug_feet_per_second = self.__convert_from_base(ImpulseUnits.SlugFootPerSecond)
        return self.__slug_feet_per_second

    
    @property
    def nanonewton_seconds(self) -> float:
        """
        
        """
        if self.__nanonewton_seconds != None:
            return self.__nanonewton_seconds
        self.__nanonewton_seconds = self.__convert_from_base(ImpulseUnits.NanonewtonSecond)
        return self.__nanonewton_seconds

    
    @property
    def micronewton_seconds(self) -> float:
        """
        
        """
        if self.__micronewton_seconds != None:
            return self.__micronewton_seconds
        self.__micronewton_seconds = self.__convert_from_base(ImpulseUnits.MicronewtonSecond)
        return self.__micronewton_seconds

    
    @property
    def millinewton_seconds(self) -> float:
        """
        
        """
        if self.__millinewton_seconds != None:
            return self.__millinewton_seconds
        self.__millinewton_seconds = self.__convert_from_base(ImpulseUnits.MillinewtonSecond)
        return self.__millinewton_seconds

    
    @property
    def centinewton_seconds(self) -> float:
        """
        
        """
        if self.__centinewton_seconds != None:
            return self.__centinewton_seconds
        self.__centinewton_seconds = self.__convert_from_base(ImpulseUnits.CentinewtonSecond)
        return self.__centinewton_seconds

    
    @property
    def decinewton_seconds(self) -> float:
        """
        
        """
        if self.__decinewton_seconds != None:
            return self.__decinewton_seconds
        self.__decinewton_seconds = self.__convert_from_base(ImpulseUnits.DecinewtonSecond)
        return self.__decinewton_seconds

    
    @property
    def decanewton_seconds(self) -> float:
        """
        
        """
        if self.__decanewton_seconds != None:
            return self.__decanewton_seconds
        self.__decanewton_seconds = self.__convert_from_base(ImpulseUnits.DecanewtonSecond)
        return self.__decanewton_seconds

    
    @property
    def kilonewton_seconds(self) -> float:
        """
        
        """
        if self.__kilonewton_seconds != None:
            return self.__kilonewton_seconds
        self.__kilonewton_seconds = self.__convert_from_base(ImpulseUnits.KilonewtonSecond)
        return self.__kilonewton_seconds

    
    @property
    def meganewton_seconds(self) -> float:
        """
        
        """
        if self.__meganewton_seconds != None:
            return self.__meganewton_seconds
        self.__meganewton_seconds = self.__convert_from_base(ImpulseUnits.MeganewtonSecond)
        return self.__meganewton_seconds

    
    def to_string(self, unit: ImpulseUnits = ImpulseUnits.NewtonSecond) -> string:
        """
        Format the Impulse to string.
        Note! the default format for Impulse is NewtonSecond.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ImpulseUnits.KilogramMeterPerSecond:
            return f"""{self.kilogram_meters_per_second} kg·m/s"""
        
        if unit == ImpulseUnits.NewtonSecond:
            return f"""{self.newton_seconds} N·s"""
        
        if unit == ImpulseUnits.PoundFootPerSecond:
            return f"""{self.pound_feet_per_second} lb·ft/s"""
        
        if unit == ImpulseUnits.PoundForceSecond:
            return f"""{self.pound_force_seconds} lbf·s"""
        
        if unit == ImpulseUnits.SlugFootPerSecond:
            return f"""{self.slug_feet_per_second} slug·ft/s"""
        
        if unit == ImpulseUnits.NanonewtonSecond:
            return f"""{self.nanonewton_seconds} """
        
        if unit == ImpulseUnits.MicronewtonSecond:
            return f"""{self.micronewton_seconds} """
        
        if unit == ImpulseUnits.MillinewtonSecond:
            return f"""{self.millinewton_seconds} """
        
        if unit == ImpulseUnits.CentinewtonSecond:
            return f"""{self.centinewton_seconds} """
        
        if unit == ImpulseUnits.DecinewtonSecond:
            return f"""{self.decinewton_seconds} """
        
        if unit == ImpulseUnits.DecanewtonSecond:
            return f"""{self.decanewton_seconds} """
        
        if unit == ImpulseUnits.KilonewtonSecond:
            return f"""{self.kilonewton_seconds} """
        
        if unit == ImpulseUnits.MeganewtonSecond:
            return f"""{self.meganewton_seconds} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ImpulseUnits = ImpulseUnits.NewtonSecond) -> string:
        """
        Get Impulse unit abbreviation.
        Note! the default abbreviation for Impulse is NewtonSecond.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ImpulseUnits.KilogramMeterPerSecond:
            return """kg·m/s"""
        
        if unit_abbreviation == ImpulseUnits.NewtonSecond:
            return """N·s"""
        
        if unit_abbreviation == ImpulseUnits.PoundFootPerSecond:
            return """lb·ft/s"""
        
        if unit_abbreviation == ImpulseUnits.PoundForceSecond:
            return """lbf·s"""
        
        if unit_abbreviation == ImpulseUnits.SlugFootPerSecond:
            return """slug·ft/s"""
        
        if unit_abbreviation == ImpulseUnits.NanonewtonSecond:
            return """"""
        
        if unit_abbreviation == ImpulseUnits.MicronewtonSecond:
            return """"""
        
        if unit_abbreviation == ImpulseUnits.MillinewtonSecond:
            return """"""
        
        if unit_abbreviation == ImpulseUnits.CentinewtonSecond:
            return """"""
        
        if unit_abbreviation == ImpulseUnits.DecinewtonSecond:
            return """"""
        
        if unit_abbreviation == ImpulseUnits.DecanewtonSecond:
            return """"""
        
        if unit_abbreviation == ImpulseUnits.KilonewtonSecond:
            return """"""
        
        if unit_abbreviation == ImpulseUnits.MeganewtonSecond:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, Impulse):
            raise TypeError("unsupported operand type(s) for +: 'Impulse' and '{}'".format(type(other).__name__))
        return Impulse(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, Impulse):
            raise TypeError("unsupported operand type(s) for *: 'Impulse' and '{}'".format(type(other).__name__))
        return Impulse(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, Impulse):
            raise TypeError("unsupported operand type(s) for -: 'Impulse' and '{}'".format(type(other).__name__))
        return Impulse(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, Impulse):
            raise TypeError("unsupported operand type(s) for /: 'Impulse' and '{}'".format(type(other).__name__))
        return Impulse(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, Impulse):
            raise TypeError("unsupported operand type(s) for %: 'Impulse' and '{}'".format(type(other).__name__))
        return Impulse(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, Impulse):
            raise TypeError("unsupported operand type(s) for **: 'Impulse' and '{}'".format(type(other).__name__))
        return Impulse(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, Impulse):
            raise TypeError("unsupported operand type(s) for ==: 'Impulse' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, Impulse):
            raise TypeError("unsupported operand type(s) for <: 'Impulse' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, Impulse):
            raise TypeError("unsupported operand type(s) for >: 'Impulse' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, Impulse):
            raise TypeError("unsupported operand type(s) for <=: 'Impulse' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, Impulse):
            raise TypeError("unsupported operand type(s) for >=: 'Impulse' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class LuminousFluxUnits(Enum):
        """
            LuminousFluxUnits enumeration
        """
        
        Lumen = 'lumen'
        """
            
        """
        

class LuminousFlux:
    """
    In photometry, luminous flux or luminous power is the measure of the perceived power of light.

    Args:
        value (float): The value.
        from_unit (LuminousFluxUnits): The LuminousFlux unit to create from, The default unit is Lumen
    """
    def __init__(self, value: float, from_unit: LuminousFluxUnits = LuminousFluxUnits.Lumen):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__lumens = None
        

    def __convert_from_base(self, from_unit: LuminousFluxUnits) -> float:
        value = self.__value
        
        if from_unit == LuminousFluxUnits.Lumen:
            return (value)
        
        return None


    def __convert_to_base(self, value: float, to_unit: LuminousFluxUnits) -> float:
        
        if to_unit == LuminousFluxUnits.Lumen:
            return (value)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_lumens(lumens: float):
        """
        Create a new instance of LuminousFlux from a value in lumens.

        

        :param meters: The LuminousFlux value in lumens.
        :type lumens: float
        :return: A new instance of LuminousFlux.
        :rtype: LuminousFlux
        """
        return LuminousFlux(lumens, LuminousFluxUnits.Lumen)

    
    @property
    def lumens(self) -> float:
        """
        
        """
        if self.__lumens != None:
            return self.__lumens
        self.__lumens = self.__convert_from_base(LuminousFluxUnits.Lumen)
        return self.__lumens

    
    def to_string(self, unit: LuminousFluxUnits = LuminousFluxUnits.Lumen) -> string:
        """
        Format the LuminousFlux to string.
        Note! the default format for LuminousFlux is Lumen.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == LuminousFluxUnits.Lumen:
            return f"""{self.lumens} lm"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: LuminousFluxUnits = LuminousFluxUnits.Lumen) -> string:
        """
        Get LuminousFlux unit abbreviation.
        Note! the default abbreviation for LuminousFlux is Lumen.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == LuminousFluxUnits.Lumen:
            return """lm"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, LuminousFlux):
            raise TypeError("unsupported operand type(s) for +: 'LuminousFlux' and '{}'".format(type(other).__name__))
        return LuminousFlux(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, LuminousFlux):
            raise TypeError("unsupported operand type(s) for *: 'LuminousFlux' and '{}'".format(type(other).__name__))
        return LuminousFlux(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, LuminousFlux):
            raise TypeError("unsupported operand type(s) for -: 'LuminousFlux' and '{}'".format(type(other).__name__))
        return LuminousFlux(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, LuminousFlux):
            raise TypeError("unsupported operand type(s) for /: 'LuminousFlux' and '{}'".format(type(other).__name__))
        return LuminousFlux(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, LuminousFlux):
            raise TypeError("unsupported operand type(s) for %: 'LuminousFlux' and '{}'".format(type(other).__name__))
        return LuminousFlux(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, LuminousFlux):
            raise TypeError("unsupported operand type(s) for **: 'LuminousFlux' and '{}'".format(type(other).__name__))
        return LuminousFlux(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, LuminousFlux):
            raise TypeError("unsupported operand type(s) for ==: 'LuminousFlux' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, LuminousFlux):
            raise TypeError("unsupported operand type(s) for <: 'LuminousFlux' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, LuminousFlux):
            raise TypeError("unsupported operand type(s) for >: 'LuminousFlux' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, LuminousFlux):
            raise TypeError("unsupported operand type(s) for <=: 'LuminousFlux' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, LuminousFlux):
            raise TypeError("unsupported operand type(s) for >=: 'LuminousFlux' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class LuminosityUnits(Enum):
        """
            LuminosityUnits enumeration
        """
        
        Watt = 'watt'
        """
            
        """
        
        SolarLuminosity = 'solar_luminosity'
        """
            
        """
        
        Femtowatt = 'femtowatt'
        """
            
        """
        
        Picowatt = 'picowatt'
        """
            
        """
        
        Nanowatt = 'nanowatt'
        """
            
        """
        
        Microwatt = 'microwatt'
        """
            
        """
        
        Milliwatt = 'milliwatt'
        """
            
        """
        
        Deciwatt = 'deciwatt'
        """
            
        """
        
        Decawatt = 'decawatt'
        """
            
        """
        
        Kilowatt = 'kilowatt'
        """
            
        """
        
        Megawatt = 'megawatt'
        """
            
        """
        
        Gigawatt = 'gigawatt'
        """
            
        """
        
        Terawatt = 'terawatt'
        """
            
        """
        
        Petawatt = 'petawatt'
        """
            
        """
        

class Luminosity:
    """
    Luminosity is an absolute measure of radiated electromagnetic power (light), the radiant power emitted by a light-emitting object.

    Args:
        value (float): The value.
        from_unit (LuminosityUnits): The Luminosity unit to create from, The default unit is Watt
    """
    def __init__(self, value: float, from_unit: LuminosityUnits = LuminosityUnits.Watt):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__watts = None
        
        self.__solar_luminosities = None
        
        self.__femtowatts = None
        
        self.__picowatts = None
        
        self.__nanowatts = None
        
        self.__microwatts = None
        
        self.__milliwatts = None
        
        self.__deciwatts = None
        
        self.__decawatts = None
        
        self.__kilowatts = None
        
        self.__megawatts = None
        
        self.__gigawatts = None
        
        self.__terawatts = None
        
        self.__petawatts = None
        

    def __convert_from_base(self, from_unit: LuminosityUnits) -> float:
        value = self.__value
        
        if from_unit == LuminosityUnits.Watt:
            return (value)
        
        if from_unit == LuminosityUnits.SolarLuminosity:
            return (value / 3.846e26)
        
        if from_unit == LuminosityUnits.Femtowatt:
            return ((value) / 1e-15)
        
        if from_unit == LuminosityUnits.Picowatt:
            return ((value) / 1e-12)
        
        if from_unit == LuminosityUnits.Nanowatt:
            return ((value) / 1e-09)
        
        if from_unit == LuminosityUnits.Microwatt:
            return ((value) / 1e-06)
        
        if from_unit == LuminosityUnits.Milliwatt:
            return ((value) / 0.001)
        
        if from_unit == LuminosityUnits.Deciwatt:
            return ((value) / 0.1)
        
        if from_unit == LuminosityUnits.Decawatt:
            return ((value) / 10.0)
        
        if from_unit == LuminosityUnits.Kilowatt:
            return ((value) / 1000.0)
        
        if from_unit == LuminosityUnits.Megawatt:
            return ((value) / 1000000.0)
        
        if from_unit == LuminosityUnits.Gigawatt:
            return ((value) / 1000000000.0)
        
        if from_unit == LuminosityUnits.Terawatt:
            return ((value) / 1000000000000.0)
        
        if from_unit == LuminosityUnits.Petawatt:
            return ((value) / 1000000000000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: LuminosityUnits) -> float:
        
        if to_unit == LuminosityUnits.Watt:
            return (value)
        
        if to_unit == LuminosityUnits.SolarLuminosity:
            return (value * 3.846e26)
        
        if to_unit == LuminosityUnits.Femtowatt:
            return ((value) * 1e-15)
        
        if to_unit == LuminosityUnits.Picowatt:
            return ((value) * 1e-12)
        
        if to_unit == LuminosityUnits.Nanowatt:
            return ((value) * 1e-09)
        
        if to_unit == LuminosityUnits.Microwatt:
            return ((value) * 1e-06)
        
        if to_unit == LuminosityUnits.Milliwatt:
            return ((value) * 0.001)
        
        if to_unit == LuminosityUnits.Deciwatt:
            return ((value) * 0.1)
        
        if to_unit == LuminosityUnits.Decawatt:
            return ((value) * 10.0)
        
        if to_unit == LuminosityUnits.Kilowatt:
            return ((value) * 1000.0)
        
        if to_unit == LuminosityUnits.Megawatt:
            return ((value) * 1000000.0)
        
        if to_unit == LuminosityUnits.Gigawatt:
            return ((value) * 1000000000.0)
        
        if to_unit == LuminosityUnits.Terawatt:
            return ((value) * 1000000000000.0)
        
        if to_unit == LuminosityUnits.Petawatt:
            return ((value) * 1000000000000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_watts(watts: float):
        """
        Create a new instance of Luminosity from a value in watts.

        

        :param meters: The Luminosity value in watts.
        :type watts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(watts, LuminosityUnits.Watt)

    
    @staticmethod
    def from_solar_luminosities(solar_luminosities: float):
        """
        Create a new instance of Luminosity from a value in solar_luminosities.

        

        :param meters: The Luminosity value in solar_luminosities.
        :type solar_luminosities: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(solar_luminosities, LuminosityUnits.SolarLuminosity)

    
    @staticmethod
    def from_femtowatts(femtowatts: float):
        """
        Create a new instance of Luminosity from a value in femtowatts.

        

        :param meters: The Luminosity value in femtowatts.
        :type femtowatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(femtowatts, LuminosityUnits.Femtowatt)

    
    @staticmethod
    def from_picowatts(picowatts: float):
        """
        Create a new instance of Luminosity from a value in picowatts.

        

        :param meters: The Luminosity value in picowatts.
        :type picowatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(picowatts, LuminosityUnits.Picowatt)

    
    @staticmethod
    def from_nanowatts(nanowatts: float):
        """
        Create a new instance of Luminosity from a value in nanowatts.

        

        :param meters: The Luminosity value in nanowatts.
        :type nanowatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(nanowatts, LuminosityUnits.Nanowatt)

    
    @staticmethod
    def from_microwatts(microwatts: float):
        """
        Create a new instance of Luminosity from a value in microwatts.

        

        :param meters: The Luminosity value in microwatts.
        :type microwatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(microwatts, LuminosityUnits.Microwatt)

    
    @staticmethod
    def from_milliwatts(milliwatts: float):
        """
        Create a new instance of Luminosity from a value in milliwatts.

        

        :param meters: The Luminosity value in milliwatts.
        :type milliwatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(milliwatts, LuminosityUnits.Milliwatt)

    
    @staticmethod
    def from_deciwatts(deciwatts: float):
        """
        Create a new instance of Luminosity from a value in deciwatts.

        

        :param meters: The Luminosity value in deciwatts.
        :type deciwatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(deciwatts, LuminosityUnits.Deciwatt)

    
    @staticmethod
    def from_decawatts(decawatts: float):
        """
        Create a new instance of Luminosity from a value in decawatts.

        

        :param meters: The Luminosity value in decawatts.
        :type decawatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(decawatts, LuminosityUnits.Decawatt)

    
    @staticmethod
    def from_kilowatts(kilowatts: float):
        """
        Create a new instance of Luminosity from a value in kilowatts.

        

        :param meters: The Luminosity value in kilowatts.
        :type kilowatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(kilowatts, LuminosityUnits.Kilowatt)

    
    @staticmethod
    def from_megawatts(megawatts: float):
        """
        Create a new instance of Luminosity from a value in megawatts.

        

        :param meters: The Luminosity value in megawatts.
        :type megawatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(megawatts, LuminosityUnits.Megawatt)

    
    @staticmethod
    def from_gigawatts(gigawatts: float):
        """
        Create a new instance of Luminosity from a value in gigawatts.

        

        :param meters: The Luminosity value in gigawatts.
        :type gigawatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(gigawatts, LuminosityUnits.Gigawatt)

    
    @staticmethod
    def from_terawatts(terawatts: float):
        """
        Create a new instance of Luminosity from a value in terawatts.

        

        :param meters: The Luminosity value in terawatts.
        :type terawatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(terawatts, LuminosityUnits.Terawatt)

    
    @staticmethod
    def from_petawatts(petawatts: float):
        """
        Create a new instance of Luminosity from a value in petawatts.

        

        :param meters: The Luminosity value in petawatts.
        :type petawatts: float
        :return: A new instance of Luminosity.
        :rtype: Luminosity
        """
        return Luminosity(petawatts, LuminosityUnits.Petawatt)

    
    @property
    def watts(self) -> float:
        """
        
        """
        if self.__watts != None:
            return self.__watts
        self.__watts = self.__convert_from_base(LuminosityUnits.Watt)
        return self.__watts

    
    @property
    def solar_luminosities(self) -> float:
        """
        
        """
        if self.__solar_luminosities != None:
            return self.__solar_luminosities
        self.__solar_luminosities = self.__convert_from_base(LuminosityUnits.SolarLuminosity)
        return self.__solar_luminosities

    
    @property
    def femtowatts(self) -> float:
        """
        
        """
        if self.__femtowatts != None:
            return self.__femtowatts
        self.__femtowatts = self.__convert_from_base(LuminosityUnits.Femtowatt)
        return self.__femtowatts

    
    @property
    def picowatts(self) -> float:
        """
        
        """
        if self.__picowatts != None:
            return self.__picowatts
        self.__picowatts = self.__convert_from_base(LuminosityUnits.Picowatt)
        return self.__picowatts

    
    @property
    def nanowatts(self) -> float:
        """
        
        """
        if self.__nanowatts != None:
            return self.__nanowatts
        self.__nanowatts = self.__convert_from_base(LuminosityUnits.Nanowatt)
        return self.__nanowatts

    
    @property
    def microwatts(self) -> float:
        """
        
        """
        if self.__microwatts != None:
            return self.__microwatts
        self.__microwatts = self.__convert_from_base(LuminosityUnits.Microwatt)
        return self.__microwatts

    
    @property
    def milliwatts(self) -> float:
        """
        
        """
        if self.__milliwatts != None:
            return self.__milliwatts
        self.__milliwatts = self.__convert_from_base(LuminosityUnits.Milliwatt)
        return self.__milliwatts

    
    @property
    def deciwatts(self) -> float:
        """
        
        """
        if self.__deciwatts != None:
            return self.__deciwatts
        self.__deciwatts = self.__convert_from_base(LuminosityUnits.Deciwatt)
        return self.__deciwatts

    
    @property
    def decawatts(self) -> float:
        """
        
        """
        if self.__decawatts != None:
            return self.__decawatts
        self.__decawatts = self.__convert_from_base(LuminosityUnits.Decawatt)
        return self.__decawatts

    
    @property
    def kilowatts(self) -> float:
        """
        
        """
        if self.__kilowatts != None:
            return self.__kilowatts
        self.__kilowatts = self.__convert_from_base(LuminosityUnits.Kilowatt)
        return self.__kilowatts

    
    @property
    def megawatts(self) -> float:
        """
        
        """
        if self.__megawatts != None:
            return self.__megawatts
        self.__megawatts = self.__convert_from_base(LuminosityUnits.Megawatt)
        return self.__megawatts

    
    @property
    def gigawatts(self) -> float:
        """
        
        """
        if self.__gigawatts != None:
            return self.__gigawatts
        self.__gigawatts = self.__convert_from_base(LuminosityUnits.Gigawatt)
        return self.__gigawatts

    
    @property
    def terawatts(self) -> float:
        """
        
        """
        if self.__terawatts != None:
            return self.__terawatts
        self.__terawatts = self.__convert_from_base(LuminosityUnits.Terawatt)
        return self.__terawatts

    
    @property
    def petawatts(self) -> float:
        """
        
        """
        if self.__petawatts != None:
            return self.__petawatts
        self.__petawatts = self.__convert_from_base(LuminosityUnits.Petawatt)
        return self.__petawatts

    
    def to_string(self, unit: LuminosityUnits = LuminosityUnits.Watt) -> string:
        """
        Format the Luminosity to string.
        Note! the default format for Luminosity is Watt.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == LuminosityUnits.Watt:
            return f"""{self.watts} W"""
        
        if unit == LuminosityUnits.SolarLuminosity:
            return f"""{self.solar_luminosities} L⊙"""
        
        if unit == LuminosityUnits.Femtowatt:
            return f"""{self.femtowatts} """
        
        if unit == LuminosityUnits.Picowatt:
            return f"""{self.picowatts} """
        
        if unit == LuminosityUnits.Nanowatt:
            return f"""{self.nanowatts} """
        
        if unit == LuminosityUnits.Microwatt:
            return f"""{self.microwatts} """
        
        if unit == LuminosityUnits.Milliwatt:
            return f"""{self.milliwatts} """
        
        if unit == LuminosityUnits.Deciwatt:
            return f"""{self.deciwatts} """
        
        if unit == LuminosityUnits.Decawatt:
            return f"""{self.decawatts} """
        
        if unit == LuminosityUnits.Kilowatt:
            return f"""{self.kilowatts} """
        
        if unit == LuminosityUnits.Megawatt:
            return f"""{self.megawatts} """
        
        if unit == LuminosityUnits.Gigawatt:
            return f"""{self.gigawatts} """
        
        if unit == LuminosityUnits.Terawatt:
            return f"""{self.terawatts} """
        
        if unit == LuminosityUnits.Petawatt:
            return f"""{self.petawatts} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: LuminosityUnits = LuminosityUnits.Watt) -> string:
        """
        Get Luminosity unit abbreviation.
        Note! the default abbreviation for Luminosity is Watt.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == LuminosityUnits.Watt:
            return """W"""
        
        if unit_abbreviation == LuminosityUnits.SolarLuminosity:
            return """L⊙"""
        
        if unit_abbreviation == LuminosityUnits.Femtowatt:
            return """"""
        
        if unit_abbreviation == LuminosityUnits.Picowatt:
            return """"""
        
        if unit_abbreviation == LuminosityUnits.Nanowatt:
            return """"""
        
        if unit_abbreviation == LuminosityUnits.Microwatt:
            return """"""
        
        if unit_abbreviation == LuminosityUnits.Milliwatt:
            return """"""
        
        if unit_abbreviation == LuminosityUnits.Deciwatt:
            return """"""
        
        if unit_abbreviation == LuminosityUnits.Decawatt:
            return """"""
        
        if unit_abbreviation == LuminosityUnits.Kilowatt:
            return """"""
        
        if unit_abbreviation == LuminosityUnits.Megawatt:
            return """"""
        
        if unit_abbreviation == LuminosityUnits.Gigawatt:
            return """"""
        
        if unit_abbreviation == LuminosityUnits.Terawatt:
            return """"""
        
        if unit_abbreviation == LuminosityUnits.Petawatt:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, Luminosity):
            raise TypeError("unsupported operand type(s) for +: 'Luminosity' and '{}'".format(type(other).__name__))
        return Luminosity(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, Luminosity):
            raise TypeError("unsupported operand type(s) for *: 'Luminosity' and '{}'".format(type(other).__name__))
        return Luminosity(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, Luminosity):
            raise TypeError("unsupported operand type(s) for -: 'Luminosity' and '{}'".format(type(other).__name__))
        return Luminosity(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, Luminosity):
            raise TypeError("unsupported operand type(s) for /: 'Luminosity' and '{}'".format(type(other).__name__))
        return Luminosity(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, Luminosity):
            raise TypeError("unsupported operand type(s) for %: 'Luminosity' and '{}'".format(type(other).__name__))
        return Luminosity(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, Luminosity):
            raise TypeError("unsupported operand type(s) for **: 'Luminosity' and '{}'".format(type(other).__name__))
        return Luminosity(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, Luminosity):
            raise TypeError("unsupported operand type(s) for ==: 'Luminosity' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, Luminosity):
            raise TypeError("unsupported operand type(s) for <: 'Luminosity' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, Luminosity):
            raise TypeError("unsupported operand type(s) for >: 'Luminosity' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, Luminosity):
            raise TypeError("unsupported operand type(s) for <=: 'Luminosity' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, Luminosity):
            raise TypeError("unsupported operand type(s) for >=: 'Luminosity' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class MagneticFluxUnits(Enum):
        """
            MagneticFluxUnits enumeration
        """
        
        Weber = 'weber'
        """
            
        """
        

class MagneticFlux:
    """
    In physics, specifically electromagnetism, the magnetic flux through a surface is the surface integral of the normal component of the magnetic field B passing through that surface.

    Args:
        value (float): The value.
        from_unit (MagneticFluxUnits): The MagneticFlux unit to create from, The default unit is Weber
    """
    def __init__(self, value: float, from_unit: MagneticFluxUnits = MagneticFluxUnits.Weber):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__webers = None
        

    def __convert_from_base(self, from_unit: MagneticFluxUnits) -> float:
        value = self.__value
        
        if from_unit == MagneticFluxUnits.Weber:
            return (value)
        
        return None


    def __convert_to_base(self, value: float, to_unit: MagneticFluxUnits) -> float:
        
        if to_unit == MagneticFluxUnits.Weber:
            return (value)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_webers(webers: float):
        """
        Create a new instance of MagneticFlux from a value in webers.

        

        :param meters: The MagneticFlux value in webers.
        :type webers: float
        :return: A new instance of MagneticFlux.
        :rtype: MagneticFlux
        """
        return MagneticFlux(webers, MagneticFluxUnits.Weber)

    
    @property
    def webers(self) -> float:
        """
        
        """
        if self.__webers != None:
            return self.__webers
        self.__webers = self.__convert_from_base(MagneticFluxUnits.Weber)
        return self.__webers

    
    def to_string(self, unit: MagneticFluxUnits = MagneticFluxUnits.Weber) -> string:
        """
        Format the MagneticFlux to string.
        Note! the default format for MagneticFlux is Weber.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == MagneticFluxUnits.Weber:
            return f"""{self.webers} Wb"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: MagneticFluxUnits = MagneticFluxUnits.Weber) -> string:
        """
        Get MagneticFlux unit abbreviation.
        Note! the default abbreviation for MagneticFlux is Weber.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == MagneticFluxUnits.Weber:
            return """Wb"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, MagneticFlux):
            raise TypeError("unsupported operand type(s) for +: 'MagneticFlux' and '{}'".format(type(other).__name__))
        return MagneticFlux(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, MagneticFlux):
            raise TypeError("unsupported operand type(s) for *: 'MagneticFlux' and '{}'".format(type(other).__name__))
        return MagneticFlux(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, MagneticFlux):
            raise TypeError("unsupported operand type(s) for -: 'MagneticFlux' and '{}'".format(type(other).__name__))
        return MagneticFlux(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, MagneticFlux):
            raise TypeError("unsupported operand type(s) for /: 'MagneticFlux' and '{}'".format(type(other).__name__))
        return MagneticFlux(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, MagneticFlux):
            raise TypeError("unsupported operand type(s) for %: 'MagneticFlux' and '{}'".format(type(other).__name__))
        return MagneticFlux(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, MagneticFlux):
            raise TypeError("unsupported operand type(s) for **: 'MagneticFlux' and '{}'".format(type(other).__name__))
        return MagneticFlux(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, MagneticFlux):
            raise TypeError("unsupported operand type(s) for ==: 'MagneticFlux' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, MagneticFlux):
            raise TypeError("unsupported operand type(s) for <: 'MagneticFlux' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, MagneticFlux):
            raise TypeError("unsupported operand type(s) for >: 'MagneticFlux' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, MagneticFlux):
            raise TypeError("unsupported operand type(s) for <=: 'MagneticFlux' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, MagneticFlux):
            raise TypeError("unsupported operand type(s) for >=: 'MagneticFlux' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class PorousMediumPermeabilityUnits(Enum):
        """
            PorousMediumPermeabilityUnits enumeration
        """
        
        Darcy = 'darcy'
        """
            
        """
        
        SquareMeter = 'square_meter'
        """
            
        """
        
        SquareCentimeter = 'square_centimeter'
        """
            
        """
        
        Microdarcy = 'microdarcy'
        """
            
        """
        
        Millidarcy = 'millidarcy'
        """
            
        """
        

class PorousMediumPermeability:
    """
    None

    Args:
        value (float): The value.
        from_unit (PorousMediumPermeabilityUnits): The PorousMediumPermeability unit to create from, The default unit is SquareMeter
    """
    def __init__(self, value: float, from_unit: PorousMediumPermeabilityUnits = PorousMediumPermeabilityUnits.SquareMeter):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__darcys = None
        
        self.__square_meters = None
        
        self.__square_centimeters = None
        
        self.__microdarcys = None
        
        self.__millidarcys = None
        

    def __convert_from_base(self, from_unit: PorousMediumPermeabilityUnits) -> float:
        value = self.__value
        
        if from_unit == PorousMediumPermeabilityUnits.Darcy:
            return (value / 9.869233e-13)
        
        if from_unit == PorousMediumPermeabilityUnits.SquareMeter:
            return (value)
        
        if from_unit == PorousMediumPermeabilityUnits.SquareCentimeter:
            return (value / 1e-4)
        
        if from_unit == PorousMediumPermeabilityUnits.Microdarcy:
            return ((value / 9.869233e-13) / 1e-06)
        
        if from_unit == PorousMediumPermeabilityUnits.Millidarcy:
            return ((value / 9.869233e-13) / 0.001)
        
        return None


    def __convert_to_base(self, value: float, to_unit: PorousMediumPermeabilityUnits) -> float:
        
        if to_unit == PorousMediumPermeabilityUnits.Darcy:
            return (value * 9.869233e-13)
        
        if to_unit == PorousMediumPermeabilityUnits.SquareMeter:
            return (value)
        
        if to_unit == PorousMediumPermeabilityUnits.SquareCentimeter:
            return (value * 1e-4)
        
        if to_unit == PorousMediumPermeabilityUnits.Microdarcy:
            return ((value * 9.869233e-13) * 1e-06)
        
        if to_unit == PorousMediumPermeabilityUnits.Millidarcy:
            return ((value * 9.869233e-13) * 0.001)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_darcys(darcys: float):
        """
        Create a new instance of PorousMediumPermeability from a value in darcys.

        

        :param meters: The PorousMediumPermeability value in darcys.
        :type darcys: float
        :return: A new instance of PorousMediumPermeability.
        :rtype: PorousMediumPermeability
        """
        return PorousMediumPermeability(darcys, PorousMediumPermeabilityUnits.Darcy)

    
    @staticmethod
    def from_square_meters(square_meters: float):
        """
        Create a new instance of PorousMediumPermeability from a value in square_meters.

        

        :param meters: The PorousMediumPermeability value in square_meters.
        :type square_meters: float
        :return: A new instance of PorousMediumPermeability.
        :rtype: PorousMediumPermeability
        """
        return PorousMediumPermeability(square_meters, PorousMediumPermeabilityUnits.SquareMeter)

    
    @staticmethod
    def from_square_centimeters(square_centimeters: float):
        """
        Create a new instance of PorousMediumPermeability from a value in square_centimeters.

        

        :param meters: The PorousMediumPermeability value in square_centimeters.
        :type square_centimeters: float
        :return: A new instance of PorousMediumPermeability.
        :rtype: PorousMediumPermeability
        """
        return PorousMediumPermeability(square_centimeters, PorousMediumPermeabilityUnits.SquareCentimeter)

    
    @staticmethod
    def from_microdarcys(microdarcys: float):
        """
        Create a new instance of PorousMediumPermeability from a value in microdarcys.

        

        :param meters: The PorousMediumPermeability value in microdarcys.
        :type microdarcys: float
        :return: A new instance of PorousMediumPermeability.
        :rtype: PorousMediumPermeability
        """
        return PorousMediumPermeability(microdarcys, PorousMediumPermeabilityUnits.Microdarcy)

    
    @staticmethod
    def from_millidarcys(millidarcys: float):
        """
        Create a new instance of PorousMediumPermeability from a value in millidarcys.

        

        :param meters: The PorousMediumPermeability value in millidarcys.
        :type millidarcys: float
        :return: A new instance of PorousMediumPermeability.
        :rtype: PorousMediumPermeability
        """
        return PorousMediumPermeability(millidarcys, PorousMediumPermeabilityUnits.Millidarcy)

    
    @property
    def darcys(self) -> float:
        """
        
        """
        if self.__darcys != None:
            return self.__darcys
        self.__darcys = self.__convert_from_base(PorousMediumPermeabilityUnits.Darcy)
        return self.__darcys

    
    @property
    def square_meters(self) -> float:
        """
        
        """
        if self.__square_meters != None:
            return self.__square_meters
        self.__square_meters = self.__convert_from_base(PorousMediumPermeabilityUnits.SquareMeter)
        return self.__square_meters

    
    @property
    def square_centimeters(self) -> float:
        """
        
        """
        if self.__square_centimeters != None:
            return self.__square_centimeters
        self.__square_centimeters = self.__convert_from_base(PorousMediumPermeabilityUnits.SquareCentimeter)
        return self.__square_centimeters

    
    @property
    def microdarcys(self) -> float:
        """
        
        """
        if self.__microdarcys != None:
            return self.__microdarcys
        self.__microdarcys = self.__convert_from_base(PorousMediumPermeabilityUnits.Microdarcy)
        return self.__microdarcys

    
    @property
    def millidarcys(self) -> float:
        """
        
        """
        if self.__millidarcys != None:
            return self.__millidarcys
        self.__millidarcys = self.__convert_from_base(PorousMediumPermeabilityUnits.Millidarcy)
        return self.__millidarcys

    
    def to_string(self, unit: PorousMediumPermeabilityUnits = PorousMediumPermeabilityUnits.SquareMeter) -> string:
        """
        Format the PorousMediumPermeability to string.
        Note! the default format for PorousMediumPermeability is SquareMeter.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == PorousMediumPermeabilityUnits.Darcy:
            return f"""{self.darcys} D"""
        
        if unit == PorousMediumPermeabilityUnits.SquareMeter:
            return f"""{self.square_meters} m²"""
        
        if unit == PorousMediumPermeabilityUnits.SquareCentimeter:
            return f"""{self.square_centimeters} cm²"""
        
        if unit == PorousMediumPermeabilityUnits.Microdarcy:
            return f"""{self.microdarcys} """
        
        if unit == PorousMediumPermeabilityUnits.Millidarcy:
            return f"""{self.millidarcys} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: PorousMediumPermeabilityUnits = PorousMediumPermeabilityUnits.SquareMeter) -> string:
        """
        Get PorousMediumPermeability unit abbreviation.
        Note! the default abbreviation for PorousMediumPermeability is SquareMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == PorousMediumPermeabilityUnits.Darcy:
            return """D"""
        
        if unit_abbreviation == PorousMediumPermeabilityUnits.SquareMeter:
            return """m²"""
        
        if unit_abbreviation == PorousMediumPermeabilityUnits.SquareCentimeter:
            return """cm²"""
        
        if unit_abbreviation == PorousMediumPermeabilityUnits.Microdarcy:
            return """"""
        
        if unit_abbreviation == PorousMediumPermeabilityUnits.Millidarcy:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, PorousMediumPermeability):
            raise TypeError("unsupported operand type(s) for +: 'PorousMediumPermeability' and '{}'".format(type(other).__name__))
        return PorousMediumPermeability(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, PorousMediumPermeability):
            raise TypeError("unsupported operand type(s) for *: 'PorousMediumPermeability' and '{}'".format(type(other).__name__))
        return PorousMediumPermeability(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, PorousMediumPermeability):
            raise TypeError("unsupported operand type(s) for -: 'PorousMediumPermeability' and '{}'".format(type(other).__name__))
        return PorousMediumPermeability(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, PorousMediumPermeability):
            raise TypeError("unsupported operand type(s) for /: 'PorousMediumPermeability' and '{}'".format(type(other).__name__))
        return PorousMediumPermeability(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, PorousMediumPermeability):
            raise TypeError("unsupported operand type(s) for %: 'PorousMediumPermeability' and '{}'".format(type(other).__name__))
        return PorousMediumPermeability(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, PorousMediumPermeability):
            raise TypeError("unsupported operand type(s) for **: 'PorousMediumPermeability' and '{}'".format(type(other).__name__))
        return PorousMediumPermeability(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, PorousMediumPermeability):
            raise TypeError("unsupported operand type(s) for ==: 'PorousMediumPermeability' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, PorousMediumPermeability):
            raise TypeError("unsupported operand type(s) for <: 'PorousMediumPermeability' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, PorousMediumPermeability):
            raise TypeError("unsupported operand type(s) for >: 'PorousMediumPermeability' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, PorousMediumPermeability):
            raise TypeError("unsupported operand type(s) for <=: 'PorousMediumPermeability' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, PorousMediumPermeability):
            raise TypeError("unsupported operand type(s) for >=: 'PorousMediumPermeability' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class RotationalAccelerationUnits(Enum):
        """
            RotationalAccelerationUnits enumeration
        """
        
        RadianPerSecondSquared = 'radian_per_second_squared'
        """
            
        """
        
        DegreePerSecondSquared = 'degree_per_second_squared'
        """
            
        """
        
        RevolutionPerMinutePerSecond = 'revolution_per_minute_per_second'
        """
            
        """
        
        RevolutionPerSecondSquared = 'revolution_per_second_squared'
        """
            
        """
        

class RotationalAcceleration:
    """
    Angular acceleration is the rate of change of rotational speed.

    Args:
        value (float): The value.
        from_unit (RotationalAccelerationUnits): The RotationalAcceleration unit to create from, The default unit is RadianPerSecondSquared
    """
    def __init__(self, value: float, from_unit: RotationalAccelerationUnits = RotationalAccelerationUnits.RadianPerSecondSquared):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__radians_per_second_squared = None
        
        self.__degrees_per_second_squared = None
        
        self.__revolutions_per_minute_per_second = None
        
        self.__revolutions_per_second_squared = None
        

    def __convert_from_base(self, from_unit: RotationalAccelerationUnits) -> float:
        value = self.__value
        
        if from_unit == RotationalAccelerationUnits.RadianPerSecondSquared:
            return (value)
        
        if from_unit == RotationalAccelerationUnits.DegreePerSecondSquared:
            return ((180 / math.pi) * value)
        
        if from_unit == RotationalAccelerationUnits.RevolutionPerMinutePerSecond:
            return ((60 / (2 * math.pi)) * value)
        
        if from_unit == RotationalAccelerationUnits.RevolutionPerSecondSquared:
            return ((1 / (2 * math.pi)) * value)
        
        return None


    def __convert_to_base(self, value: float, to_unit: RotationalAccelerationUnits) -> float:
        
        if to_unit == RotationalAccelerationUnits.RadianPerSecondSquared:
            return (value)
        
        if to_unit == RotationalAccelerationUnits.DegreePerSecondSquared:
            return ((math.pi / 180) * value)
        
        if to_unit == RotationalAccelerationUnits.RevolutionPerMinutePerSecond:
            return (((2 * math.pi) / 60) * value)
        
        if to_unit == RotationalAccelerationUnits.RevolutionPerSecondSquared:
            return ((2 * math.pi) * value)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_radians_per_second_squared(radians_per_second_squared: float):
        """
        Create a new instance of RotationalAcceleration from a value in radians_per_second_squared.

        

        :param meters: The RotationalAcceleration value in radians_per_second_squared.
        :type radians_per_second_squared: float
        :return: A new instance of RotationalAcceleration.
        :rtype: RotationalAcceleration
        """
        return RotationalAcceleration(radians_per_second_squared, RotationalAccelerationUnits.RadianPerSecondSquared)

    
    @staticmethod
    def from_degrees_per_second_squared(degrees_per_second_squared: float):
        """
        Create a new instance of RotationalAcceleration from a value in degrees_per_second_squared.

        

        :param meters: The RotationalAcceleration value in degrees_per_second_squared.
        :type degrees_per_second_squared: float
        :return: A new instance of RotationalAcceleration.
        :rtype: RotationalAcceleration
        """
        return RotationalAcceleration(degrees_per_second_squared, RotationalAccelerationUnits.DegreePerSecondSquared)

    
    @staticmethod
    def from_revolutions_per_minute_per_second(revolutions_per_minute_per_second: float):
        """
        Create a new instance of RotationalAcceleration from a value in revolutions_per_minute_per_second.

        

        :param meters: The RotationalAcceleration value in revolutions_per_minute_per_second.
        :type revolutions_per_minute_per_second: float
        :return: A new instance of RotationalAcceleration.
        :rtype: RotationalAcceleration
        """
        return RotationalAcceleration(revolutions_per_minute_per_second, RotationalAccelerationUnits.RevolutionPerMinutePerSecond)

    
    @staticmethod
    def from_revolutions_per_second_squared(revolutions_per_second_squared: float):
        """
        Create a new instance of RotationalAcceleration from a value in revolutions_per_second_squared.

        

        :param meters: The RotationalAcceleration value in revolutions_per_second_squared.
        :type revolutions_per_second_squared: float
        :return: A new instance of RotationalAcceleration.
        :rtype: RotationalAcceleration
        """
        return RotationalAcceleration(revolutions_per_second_squared, RotationalAccelerationUnits.RevolutionPerSecondSquared)

    
    @property
    def radians_per_second_squared(self) -> float:
        """
        
        """
        if self.__radians_per_second_squared != None:
            return self.__radians_per_second_squared
        self.__radians_per_second_squared = self.__convert_from_base(RotationalAccelerationUnits.RadianPerSecondSquared)
        return self.__radians_per_second_squared

    
    @property
    def degrees_per_second_squared(self) -> float:
        """
        
        """
        if self.__degrees_per_second_squared != None:
            return self.__degrees_per_second_squared
        self.__degrees_per_second_squared = self.__convert_from_base(RotationalAccelerationUnits.DegreePerSecondSquared)
        return self.__degrees_per_second_squared

    
    @property
    def revolutions_per_minute_per_second(self) -> float:
        """
        
        """
        if self.__revolutions_per_minute_per_second != None:
            return self.__revolutions_per_minute_per_second
        self.__revolutions_per_minute_per_second = self.__convert_from_base(RotationalAccelerationUnits.RevolutionPerMinutePerSecond)
        return self.__revolutions_per_minute_per_second

    
    @property
    def revolutions_per_second_squared(self) -> float:
        """
        
        """
        if self.__revolutions_per_second_squared != None:
            return self.__revolutions_per_second_squared
        self.__revolutions_per_second_squared = self.__convert_from_base(RotationalAccelerationUnits.RevolutionPerSecondSquared)
        return self.__revolutions_per_second_squared

    
    def to_string(self, unit: RotationalAccelerationUnits = RotationalAccelerationUnits.RadianPerSecondSquared) -> string:
        """
        Format the RotationalAcceleration to string.
        Note! the default format for RotationalAcceleration is RadianPerSecondSquared.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == RotationalAccelerationUnits.RadianPerSecondSquared:
            return f"""{self.radians_per_second_squared} rad/s²"""
        
        if unit == RotationalAccelerationUnits.DegreePerSecondSquared:
            return f"""{self.degrees_per_second_squared} °/s²"""
        
        if unit == RotationalAccelerationUnits.RevolutionPerMinutePerSecond:
            return f"""{self.revolutions_per_minute_per_second} rpm/s"""
        
        if unit == RotationalAccelerationUnits.RevolutionPerSecondSquared:
            return f"""{self.revolutions_per_second_squared} r/s²"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: RotationalAccelerationUnits = RotationalAccelerationUnits.RadianPerSecondSquared) -> string:
        """
        Get RotationalAcceleration unit abbreviation.
        Note! the default abbreviation for RotationalAcceleration is RadianPerSecondSquared.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == RotationalAccelerationUnits.RadianPerSecondSquared:
            return """rad/s²"""
        
        if unit_abbreviation == RotationalAccelerationUnits.DegreePerSecondSquared:
            return """°/s²"""
        
        if unit_abbreviation == RotationalAccelerationUnits.RevolutionPerMinutePerSecond:
            return """rpm/s"""
        
        if unit_abbreviation == RotationalAccelerationUnits.RevolutionPerSecondSquared:
            return """r/s²"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, RotationalAcceleration):
            raise TypeError("unsupported operand type(s) for +: 'RotationalAcceleration' and '{}'".format(type(other).__name__))
        return RotationalAcceleration(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, RotationalAcceleration):
            raise TypeError("unsupported operand type(s) for *: 'RotationalAcceleration' and '{}'".format(type(other).__name__))
        return RotationalAcceleration(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, RotationalAcceleration):
            raise TypeError("unsupported operand type(s) for -: 'RotationalAcceleration' and '{}'".format(type(other).__name__))
        return RotationalAcceleration(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, RotationalAcceleration):
            raise TypeError("unsupported operand type(s) for /: 'RotationalAcceleration' and '{}'".format(type(other).__name__))
        return RotationalAcceleration(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, RotationalAcceleration):
            raise TypeError("unsupported operand type(s) for %: 'RotationalAcceleration' and '{}'".format(type(other).__name__))
        return RotationalAcceleration(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, RotationalAcceleration):
            raise TypeError("unsupported operand type(s) for **: 'RotationalAcceleration' and '{}'".format(type(other).__name__))
        return RotationalAcceleration(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, RotationalAcceleration):
            raise TypeError("unsupported operand type(s) for ==: 'RotationalAcceleration' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, RotationalAcceleration):
            raise TypeError("unsupported operand type(s) for <: 'RotationalAcceleration' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, RotationalAcceleration):
            raise TypeError("unsupported operand type(s) for >: 'RotationalAcceleration' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, RotationalAcceleration):
            raise TypeError("unsupported operand type(s) for <=: 'RotationalAcceleration' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, RotationalAcceleration):
            raise TypeError("unsupported operand type(s) for >=: 'RotationalAcceleration' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ElectricPotentialChangeRateUnits(Enum):
        """
            ElectricPotentialChangeRateUnits enumeration
        """
        
        VoltPerSecond = 'volt_per_second'
        """
            
        """
        
        VoltPerMicrosecond = 'volt_per_microsecond'
        """
            
        """
        
        VoltPerMinute = 'volt_per_minute'
        """
            
        """
        
        VoltPerHour = 'volt_per_hour'
        """
            
        """
        
        MicrovoltPerSecond = 'microvolt_per_second'
        """
            
        """
        
        MillivoltPerSecond = 'millivolt_per_second'
        """
            
        """
        
        KilovoltPerSecond = 'kilovolt_per_second'
        """
            
        """
        
        MegavoltPerSecond = 'megavolt_per_second'
        """
            
        """
        
        MicrovoltPerMicrosecond = 'microvolt_per_microsecond'
        """
            
        """
        
        MillivoltPerMicrosecond = 'millivolt_per_microsecond'
        """
            
        """
        
        KilovoltPerMicrosecond = 'kilovolt_per_microsecond'
        """
            
        """
        
        MegavoltPerMicrosecond = 'megavolt_per_microsecond'
        """
            
        """
        
        MicrovoltPerMinute = 'microvolt_per_minute'
        """
            
        """
        
        MillivoltPerMinute = 'millivolt_per_minute'
        """
            
        """
        
        KilovoltPerMinute = 'kilovolt_per_minute'
        """
            
        """
        
        MegavoltPerMinute = 'megavolt_per_minute'
        """
            
        """
        
        MicrovoltPerHour = 'microvolt_per_hour'
        """
            
        """
        
        MillivoltPerHour = 'millivolt_per_hour'
        """
            
        """
        
        KilovoltPerHour = 'kilovolt_per_hour'
        """
            
        """
        
        MegavoltPerHour = 'megavolt_per_hour'
        """
            
        """
        

class ElectricPotentialChangeRate:
    """
    ElectricPotential change rate is the ratio of the electric potential change to the time during which the change occurred (value of electric potential changes per unit time).

    Args:
        value (float): The value.
        from_unit (ElectricPotentialChangeRateUnits): The ElectricPotentialChangeRate unit to create from, The default unit is VoltPerSecond
    """
    def __init__(self, value: float, from_unit: ElectricPotentialChangeRateUnits = ElectricPotentialChangeRateUnits.VoltPerSecond):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__volts_per_seconds = None
        
        self.__volts_per_microseconds = None
        
        self.__volts_per_minutes = None
        
        self.__volts_per_hours = None
        
        self.__microvolts_per_seconds = None
        
        self.__millivolts_per_seconds = None
        
        self.__kilovolts_per_seconds = None
        
        self.__megavolts_per_seconds = None
        
        self.__microvolts_per_microseconds = None
        
        self.__millivolts_per_microseconds = None
        
        self.__kilovolts_per_microseconds = None
        
        self.__megavolts_per_microseconds = None
        
        self.__microvolts_per_minutes = None
        
        self.__millivolts_per_minutes = None
        
        self.__kilovolts_per_minutes = None
        
        self.__megavolts_per_minutes = None
        
        self.__microvolts_per_hours = None
        
        self.__millivolts_per_hours = None
        
        self.__kilovolts_per_hours = None
        
        self.__megavolts_per_hours = None
        

    def __convert_from_base(self, from_unit: ElectricPotentialChangeRateUnits) -> float:
        value = self.__value
        
        if from_unit == ElectricPotentialChangeRateUnits.VoltPerSecond:
            return (value)
        
        if from_unit == ElectricPotentialChangeRateUnits.VoltPerMicrosecond:
            return (value / 1e6)
        
        if from_unit == ElectricPotentialChangeRateUnits.VoltPerMinute:
            return (value * 60)
        
        if from_unit == ElectricPotentialChangeRateUnits.VoltPerHour:
            return (value * 3600)
        
        if from_unit == ElectricPotentialChangeRateUnits.MicrovoltPerSecond:
            return ((value) / 1e-06)
        
        if from_unit == ElectricPotentialChangeRateUnits.MillivoltPerSecond:
            return ((value) / 0.001)
        
        if from_unit == ElectricPotentialChangeRateUnits.KilovoltPerSecond:
            return ((value) / 1000.0)
        
        if from_unit == ElectricPotentialChangeRateUnits.MegavoltPerSecond:
            return ((value) / 1000000.0)
        
        if from_unit == ElectricPotentialChangeRateUnits.MicrovoltPerMicrosecond:
            return ((value / 1e6) / 1e-06)
        
        if from_unit == ElectricPotentialChangeRateUnits.MillivoltPerMicrosecond:
            return ((value / 1e6) / 0.001)
        
        if from_unit == ElectricPotentialChangeRateUnits.KilovoltPerMicrosecond:
            return ((value / 1e6) / 1000.0)
        
        if from_unit == ElectricPotentialChangeRateUnits.MegavoltPerMicrosecond:
            return ((value / 1e6) / 1000000.0)
        
        if from_unit == ElectricPotentialChangeRateUnits.MicrovoltPerMinute:
            return ((value * 60) / 1e-06)
        
        if from_unit == ElectricPotentialChangeRateUnits.MillivoltPerMinute:
            return ((value * 60) / 0.001)
        
        if from_unit == ElectricPotentialChangeRateUnits.KilovoltPerMinute:
            return ((value * 60) / 1000.0)
        
        if from_unit == ElectricPotentialChangeRateUnits.MegavoltPerMinute:
            return ((value * 60) / 1000000.0)
        
        if from_unit == ElectricPotentialChangeRateUnits.MicrovoltPerHour:
            return ((value * 3600) / 1e-06)
        
        if from_unit == ElectricPotentialChangeRateUnits.MillivoltPerHour:
            return ((value * 3600) / 0.001)
        
        if from_unit == ElectricPotentialChangeRateUnits.KilovoltPerHour:
            return ((value * 3600) / 1000.0)
        
        if from_unit == ElectricPotentialChangeRateUnits.MegavoltPerHour:
            return ((value * 3600) / 1000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricPotentialChangeRateUnits) -> float:
        
        if to_unit == ElectricPotentialChangeRateUnits.VoltPerSecond:
            return (value)
        
        if to_unit == ElectricPotentialChangeRateUnits.VoltPerMicrosecond:
            return (value * 1e6)
        
        if to_unit == ElectricPotentialChangeRateUnits.VoltPerMinute:
            return (value / 60)
        
        if to_unit == ElectricPotentialChangeRateUnits.VoltPerHour:
            return (value / 3600)
        
        if to_unit == ElectricPotentialChangeRateUnits.MicrovoltPerSecond:
            return ((value) * 1e-06)
        
        if to_unit == ElectricPotentialChangeRateUnits.MillivoltPerSecond:
            return ((value) * 0.001)
        
        if to_unit == ElectricPotentialChangeRateUnits.KilovoltPerSecond:
            return ((value) * 1000.0)
        
        if to_unit == ElectricPotentialChangeRateUnits.MegavoltPerSecond:
            return ((value) * 1000000.0)
        
        if to_unit == ElectricPotentialChangeRateUnits.MicrovoltPerMicrosecond:
            return ((value * 1e6) * 1e-06)
        
        if to_unit == ElectricPotentialChangeRateUnits.MillivoltPerMicrosecond:
            return ((value * 1e6) * 0.001)
        
        if to_unit == ElectricPotentialChangeRateUnits.KilovoltPerMicrosecond:
            return ((value * 1e6) * 1000.0)
        
        if to_unit == ElectricPotentialChangeRateUnits.MegavoltPerMicrosecond:
            return ((value * 1e6) * 1000000.0)
        
        if to_unit == ElectricPotentialChangeRateUnits.MicrovoltPerMinute:
            return ((value / 60) * 1e-06)
        
        if to_unit == ElectricPotentialChangeRateUnits.MillivoltPerMinute:
            return ((value / 60) * 0.001)
        
        if to_unit == ElectricPotentialChangeRateUnits.KilovoltPerMinute:
            return ((value / 60) * 1000.0)
        
        if to_unit == ElectricPotentialChangeRateUnits.MegavoltPerMinute:
            return ((value / 60) * 1000000.0)
        
        if to_unit == ElectricPotentialChangeRateUnits.MicrovoltPerHour:
            return ((value / 3600) * 1e-06)
        
        if to_unit == ElectricPotentialChangeRateUnits.MillivoltPerHour:
            return ((value / 3600) * 0.001)
        
        if to_unit == ElectricPotentialChangeRateUnits.KilovoltPerHour:
            return ((value / 3600) * 1000.0)
        
        if to_unit == ElectricPotentialChangeRateUnits.MegavoltPerHour:
            return ((value / 3600) * 1000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_volts_per_seconds(volts_per_seconds: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in volts_per_seconds.

        

        :param meters: The ElectricPotentialChangeRate value in volts_per_seconds.
        :type volts_per_seconds: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(volts_per_seconds, ElectricPotentialChangeRateUnits.VoltPerSecond)

    
    @staticmethod
    def from_volts_per_microseconds(volts_per_microseconds: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in volts_per_microseconds.

        

        :param meters: The ElectricPotentialChangeRate value in volts_per_microseconds.
        :type volts_per_microseconds: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(volts_per_microseconds, ElectricPotentialChangeRateUnits.VoltPerMicrosecond)

    
    @staticmethod
    def from_volts_per_minutes(volts_per_minutes: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in volts_per_minutes.

        

        :param meters: The ElectricPotentialChangeRate value in volts_per_minutes.
        :type volts_per_minutes: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(volts_per_minutes, ElectricPotentialChangeRateUnits.VoltPerMinute)

    
    @staticmethod
    def from_volts_per_hours(volts_per_hours: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in volts_per_hours.

        

        :param meters: The ElectricPotentialChangeRate value in volts_per_hours.
        :type volts_per_hours: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(volts_per_hours, ElectricPotentialChangeRateUnits.VoltPerHour)

    
    @staticmethod
    def from_microvolts_per_seconds(microvolts_per_seconds: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in microvolts_per_seconds.

        

        :param meters: The ElectricPotentialChangeRate value in microvolts_per_seconds.
        :type microvolts_per_seconds: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(microvolts_per_seconds, ElectricPotentialChangeRateUnits.MicrovoltPerSecond)

    
    @staticmethod
    def from_millivolts_per_seconds(millivolts_per_seconds: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in millivolts_per_seconds.

        

        :param meters: The ElectricPotentialChangeRate value in millivolts_per_seconds.
        :type millivolts_per_seconds: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(millivolts_per_seconds, ElectricPotentialChangeRateUnits.MillivoltPerSecond)

    
    @staticmethod
    def from_kilovolts_per_seconds(kilovolts_per_seconds: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in kilovolts_per_seconds.

        

        :param meters: The ElectricPotentialChangeRate value in kilovolts_per_seconds.
        :type kilovolts_per_seconds: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(kilovolts_per_seconds, ElectricPotentialChangeRateUnits.KilovoltPerSecond)

    
    @staticmethod
    def from_megavolts_per_seconds(megavolts_per_seconds: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in megavolts_per_seconds.

        

        :param meters: The ElectricPotentialChangeRate value in megavolts_per_seconds.
        :type megavolts_per_seconds: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(megavolts_per_seconds, ElectricPotentialChangeRateUnits.MegavoltPerSecond)

    
    @staticmethod
    def from_microvolts_per_microseconds(microvolts_per_microseconds: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in microvolts_per_microseconds.

        

        :param meters: The ElectricPotentialChangeRate value in microvolts_per_microseconds.
        :type microvolts_per_microseconds: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(microvolts_per_microseconds, ElectricPotentialChangeRateUnits.MicrovoltPerMicrosecond)

    
    @staticmethod
    def from_millivolts_per_microseconds(millivolts_per_microseconds: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in millivolts_per_microseconds.

        

        :param meters: The ElectricPotentialChangeRate value in millivolts_per_microseconds.
        :type millivolts_per_microseconds: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(millivolts_per_microseconds, ElectricPotentialChangeRateUnits.MillivoltPerMicrosecond)

    
    @staticmethod
    def from_kilovolts_per_microseconds(kilovolts_per_microseconds: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in kilovolts_per_microseconds.

        

        :param meters: The ElectricPotentialChangeRate value in kilovolts_per_microseconds.
        :type kilovolts_per_microseconds: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(kilovolts_per_microseconds, ElectricPotentialChangeRateUnits.KilovoltPerMicrosecond)

    
    @staticmethod
    def from_megavolts_per_microseconds(megavolts_per_microseconds: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in megavolts_per_microseconds.

        

        :param meters: The ElectricPotentialChangeRate value in megavolts_per_microseconds.
        :type megavolts_per_microseconds: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(megavolts_per_microseconds, ElectricPotentialChangeRateUnits.MegavoltPerMicrosecond)

    
    @staticmethod
    def from_microvolts_per_minutes(microvolts_per_minutes: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in microvolts_per_minutes.

        

        :param meters: The ElectricPotentialChangeRate value in microvolts_per_minutes.
        :type microvolts_per_minutes: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(microvolts_per_minutes, ElectricPotentialChangeRateUnits.MicrovoltPerMinute)

    
    @staticmethod
    def from_millivolts_per_minutes(millivolts_per_minutes: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in millivolts_per_minutes.

        

        :param meters: The ElectricPotentialChangeRate value in millivolts_per_minutes.
        :type millivolts_per_minutes: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(millivolts_per_minutes, ElectricPotentialChangeRateUnits.MillivoltPerMinute)

    
    @staticmethod
    def from_kilovolts_per_minutes(kilovolts_per_minutes: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in kilovolts_per_minutes.

        

        :param meters: The ElectricPotentialChangeRate value in kilovolts_per_minutes.
        :type kilovolts_per_minutes: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(kilovolts_per_minutes, ElectricPotentialChangeRateUnits.KilovoltPerMinute)

    
    @staticmethod
    def from_megavolts_per_minutes(megavolts_per_minutes: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in megavolts_per_minutes.

        

        :param meters: The ElectricPotentialChangeRate value in megavolts_per_minutes.
        :type megavolts_per_minutes: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(megavolts_per_minutes, ElectricPotentialChangeRateUnits.MegavoltPerMinute)

    
    @staticmethod
    def from_microvolts_per_hours(microvolts_per_hours: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in microvolts_per_hours.

        

        :param meters: The ElectricPotentialChangeRate value in microvolts_per_hours.
        :type microvolts_per_hours: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(microvolts_per_hours, ElectricPotentialChangeRateUnits.MicrovoltPerHour)

    
    @staticmethod
    def from_millivolts_per_hours(millivolts_per_hours: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in millivolts_per_hours.

        

        :param meters: The ElectricPotentialChangeRate value in millivolts_per_hours.
        :type millivolts_per_hours: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(millivolts_per_hours, ElectricPotentialChangeRateUnits.MillivoltPerHour)

    
    @staticmethod
    def from_kilovolts_per_hours(kilovolts_per_hours: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in kilovolts_per_hours.

        

        :param meters: The ElectricPotentialChangeRate value in kilovolts_per_hours.
        :type kilovolts_per_hours: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(kilovolts_per_hours, ElectricPotentialChangeRateUnits.KilovoltPerHour)

    
    @staticmethod
    def from_megavolts_per_hours(megavolts_per_hours: float):
        """
        Create a new instance of ElectricPotentialChangeRate from a value in megavolts_per_hours.

        

        :param meters: The ElectricPotentialChangeRate value in megavolts_per_hours.
        :type megavolts_per_hours: float
        :return: A new instance of ElectricPotentialChangeRate.
        :rtype: ElectricPotentialChangeRate
        """
        return ElectricPotentialChangeRate(megavolts_per_hours, ElectricPotentialChangeRateUnits.MegavoltPerHour)

    
    @property
    def volts_per_seconds(self) -> float:
        """
        
        """
        if self.__volts_per_seconds != None:
            return self.__volts_per_seconds
        self.__volts_per_seconds = self.__convert_from_base(ElectricPotentialChangeRateUnits.VoltPerSecond)
        return self.__volts_per_seconds

    
    @property
    def volts_per_microseconds(self) -> float:
        """
        
        """
        if self.__volts_per_microseconds != None:
            return self.__volts_per_microseconds
        self.__volts_per_microseconds = self.__convert_from_base(ElectricPotentialChangeRateUnits.VoltPerMicrosecond)
        return self.__volts_per_microseconds

    
    @property
    def volts_per_minutes(self) -> float:
        """
        
        """
        if self.__volts_per_minutes != None:
            return self.__volts_per_minutes
        self.__volts_per_minutes = self.__convert_from_base(ElectricPotentialChangeRateUnits.VoltPerMinute)
        return self.__volts_per_minutes

    
    @property
    def volts_per_hours(self) -> float:
        """
        
        """
        if self.__volts_per_hours != None:
            return self.__volts_per_hours
        self.__volts_per_hours = self.__convert_from_base(ElectricPotentialChangeRateUnits.VoltPerHour)
        return self.__volts_per_hours

    
    @property
    def microvolts_per_seconds(self) -> float:
        """
        
        """
        if self.__microvolts_per_seconds != None:
            return self.__microvolts_per_seconds
        self.__microvolts_per_seconds = self.__convert_from_base(ElectricPotentialChangeRateUnits.MicrovoltPerSecond)
        return self.__microvolts_per_seconds

    
    @property
    def millivolts_per_seconds(self) -> float:
        """
        
        """
        if self.__millivolts_per_seconds != None:
            return self.__millivolts_per_seconds
        self.__millivolts_per_seconds = self.__convert_from_base(ElectricPotentialChangeRateUnits.MillivoltPerSecond)
        return self.__millivolts_per_seconds

    
    @property
    def kilovolts_per_seconds(self) -> float:
        """
        
        """
        if self.__kilovolts_per_seconds != None:
            return self.__kilovolts_per_seconds
        self.__kilovolts_per_seconds = self.__convert_from_base(ElectricPotentialChangeRateUnits.KilovoltPerSecond)
        return self.__kilovolts_per_seconds

    
    @property
    def megavolts_per_seconds(self) -> float:
        """
        
        """
        if self.__megavolts_per_seconds != None:
            return self.__megavolts_per_seconds
        self.__megavolts_per_seconds = self.__convert_from_base(ElectricPotentialChangeRateUnits.MegavoltPerSecond)
        return self.__megavolts_per_seconds

    
    @property
    def microvolts_per_microseconds(self) -> float:
        """
        
        """
        if self.__microvolts_per_microseconds != None:
            return self.__microvolts_per_microseconds
        self.__microvolts_per_microseconds = self.__convert_from_base(ElectricPotentialChangeRateUnits.MicrovoltPerMicrosecond)
        return self.__microvolts_per_microseconds

    
    @property
    def millivolts_per_microseconds(self) -> float:
        """
        
        """
        if self.__millivolts_per_microseconds != None:
            return self.__millivolts_per_microseconds
        self.__millivolts_per_microseconds = self.__convert_from_base(ElectricPotentialChangeRateUnits.MillivoltPerMicrosecond)
        return self.__millivolts_per_microseconds

    
    @property
    def kilovolts_per_microseconds(self) -> float:
        """
        
        """
        if self.__kilovolts_per_microseconds != None:
            return self.__kilovolts_per_microseconds
        self.__kilovolts_per_microseconds = self.__convert_from_base(ElectricPotentialChangeRateUnits.KilovoltPerMicrosecond)
        return self.__kilovolts_per_microseconds

    
    @property
    def megavolts_per_microseconds(self) -> float:
        """
        
        """
        if self.__megavolts_per_microseconds != None:
            return self.__megavolts_per_microseconds
        self.__megavolts_per_microseconds = self.__convert_from_base(ElectricPotentialChangeRateUnits.MegavoltPerMicrosecond)
        return self.__megavolts_per_microseconds

    
    @property
    def microvolts_per_minutes(self) -> float:
        """
        
        """
        if self.__microvolts_per_minutes != None:
            return self.__microvolts_per_minutes
        self.__microvolts_per_minutes = self.__convert_from_base(ElectricPotentialChangeRateUnits.MicrovoltPerMinute)
        return self.__microvolts_per_minutes

    
    @property
    def millivolts_per_minutes(self) -> float:
        """
        
        """
        if self.__millivolts_per_minutes != None:
            return self.__millivolts_per_minutes
        self.__millivolts_per_minutes = self.__convert_from_base(ElectricPotentialChangeRateUnits.MillivoltPerMinute)
        return self.__millivolts_per_minutes

    
    @property
    def kilovolts_per_minutes(self) -> float:
        """
        
        """
        if self.__kilovolts_per_minutes != None:
            return self.__kilovolts_per_minutes
        self.__kilovolts_per_minutes = self.__convert_from_base(ElectricPotentialChangeRateUnits.KilovoltPerMinute)
        return self.__kilovolts_per_minutes

    
    @property
    def megavolts_per_minutes(self) -> float:
        """
        
        """
        if self.__megavolts_per_minutes != None:
            return self.__megavolts_per_minutes
        self.__megavolts_per_minutes = self.__convert_from_base(ElectricPotentialChangeRateUnits.MegavoltPerMinute)
        return self.__megavolts_per_minutes

    
    @property
    def microvolts_per_hours(self) -> float:
        """
        
        """
        if self.__microvolts_per_hours != None:
            return self.__microvolts_per_hours
        self.__microvolts_per_hours = self.__convert_from_base(ElectricPotentialChangeRateUnits.MicrovoltPerHour)
        return self.__microvolts_per_hours

    
    @property
    def millivolts_per_hours(self) -> float:
        """
        
        """
        if self.__millivolts_per_hours != None:
            return self.__millivolts_per_hours
        self.__millivolts_per_hours = self.__convert_from_base(ElectricPotentialChangeRateUnits.MillivoltPerHour)
        return self.__millivolts_per_hours

    
    @property
    def kilovolts_per_hours(self) -> float:
        """
        
        """
        if self.__kilovolts_per_hours != None:
            return self.__kilovolts_per_hours
        self.__kilovolts_per_hours = self.__convert_from_base(ElectricPotentialChangeRateUnits.KilovoltPerHour)
        return self.__kilovolts_per_hours

    
    @property
    def megavolts_per_hours(self) -> float:
        """
        
        """
        if self.__megavolts_per_hours != None:
            return self.__megavolts_per_hours
        self.__megavolts_per_hours = self.__convert_from_base(ElectricPotentialChangeRateUnits.MegavoltPerHour)
        return self.__megavolts_per_hours

    
    def to_string(self, unit: ElectricPotentialChangeRateUnits = ElectricPotentialChangeRateUnits.VoltPerSecond) -> string:
        """
        Format the ElectricPotentialChangeRate to string.
        Note! the default format for ElectricPotentialChangeRate is VoltPerSecond.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ElectricPotentialChangeRateUnits.VoltPerSecond:
            return f"""{self.volts_per_seconds} V/s"""
        
        if unit == ElectricPotentialChangeRateUnits.VoltPerMicrosecond:
            return f"""{self.volts_per_microseconds} V/μs"""
        
        if unit == ElectricPotentialChangeRateUnits.VoltPerMinute:
            return f"""{self.volts_per_minutes} V/min"""
        
        if unit == ElectricPotentialChangeRateUnits.VoltPerHour:
            return f"""{self.volts_per_hours} V/h"""
        
        if unit == ElectricPotentialChangeRateUnits.MicrovoltPerSecond:
            return f"""{self.microvolts_per_seconds} """
        
        if unit == ElectricPotentialChangeRateUnits.MillivoltPerSecond:
            return f"""{self.millivolts_per_seconds} """
        
        if unit == ElectricPotentialChangeRateUnits.KilovoltPerSecond:
            return f"""{self.kilovolts_per_seconds} """
        
        if unit == ElectricPotentialChangeRateUnits.MegavoltPerSecond:
            return f"""{self.megavolts_per_seconds} """
        
        if unit == ElectricPotentialChangeRateUnits.MicrovoltPerMicrosecond:
            return f"""{self.microvolts_per_microseconds} """
        
        if unit == ElectricPotentialChangeRateUnits.MillivoltPerMicrosecond:
            return f"""{self.millivolts_per_microseconds} """
        
        if unit == ElectricPotentialChangeRateUnits.KilovoltPerMicrosecond:
            return f"""{self.kilovolts_per_microseconds} """
        
        if unit == ElectricPotentialChangeRateUnits.MegavoltPerMicrosecond:
            return f"""{self.megavolts_per_microseconds} """
        
        if unit == ElectricPotentialChangeRateUnits.MicrovoltPerMinute:
            return f"""{self.microvolts_per_minutes} """
        
        if unit == ElectricPotentialChangeRateUnits.MillivoltPerMinute:
            return f"""{self.millivolts_per_minutes} """
        
        if unit == ElectricPotentialChangeRateUnits.KilovoltPerMinute:
            return f"""{self.kilovolts_per_minutes} """
        
        if unit == ElectricPotentialChangeRateUnits.MegavoltPerMinute:
            return f"""{self.megavolts_per_minutes} """
        
        if unit == ElectricPotentialChangeRateUnits.MicrovoltPerHour:
            return f"""{self.microvolts_per_hours} """
        
        if unit == ElectricPotentialChangeRateUnits.MillivoltPerHour:
            return f"""{self.millivolts_per_hours} """
        
        if unit == ElectricPotentialChangeRateUnits.KilovoltPerHour:
            return f"""{self.kilovolts_per_hours} """
        
        if unit == ElectricPotentialChangeRateUnits.MegavoltPerHour:
            return f"""{self.megavolts_per_hours} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricPotentialChangeRateUnits = ElectricPotentialChangeRateUnits.VoltPerSecond) -> string:
        """
        Get ElectricPotentialChangeRate unit abbreviation.
        Note! the default abbreviation for ElectricPotentialChangeRate is VoltPerSecond.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.VoltPerSecond:
            return """V/s"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.VoltPerMicrosecond:
            return """V/μs"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.VoltPerMinute:
            return """V/min"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.VoltPerHour:
            return """V/h"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MicrovoltPerSecond:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MillivoltPerSecond:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.KilovoltPerSecond:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MegavoltPerSecond:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MicrovoltPerMicrosecond:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MillivoltPerMicrosecond:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.KilovoltPerMicrosecond:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MegavoltPerMicrosecond:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MicrovoltPerMinute:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MillivoltPerMinute:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.KilovoltPerMinute:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MegavoltPerMinute:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MicrovoltPerHour:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MillivoltPerHour:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.KilovoltPerHour:
            return """"""
        
        if unit_abbreviation == ElectricPotentialChangeRateUnits.MegavoltPerHour:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ElectricPotentialChangeRate):
            raise TypeError("unsupported operand type(s) for +: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
        return ElectricPotentialChangeRate(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ElectricPotentialChangeRate):
            raise TypeError("unsupported operand type(s) for *: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
        return ElectricPotentialChangeRate(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ElectricPotentialChangeRate):
            raise TypeError("unsupported operand type(s) for -: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
        return ElectricPotentialChangeRate(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ElectricPotentialChangeRate):
            raise TypeError("unsupported operand type(s) for /: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
        return ElectricPotentialChangeRate(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ElectricPotentialChangeRate):
            raise TypeError("unsupported operand type(s) for %: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
        return ElectricPotentialChangeRate(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ElectricPotentialChangeRate):
            raise TypeError("unsupported operand type(s) for **: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
        return ElectricPotentialChangeRate(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ElectricPotentialChangeRate):
            raise TypeError("unsupported operand type(s) for ==: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ElectricPotentialChangeRate):
            raise TypeError("unsupported operand type(s) for <: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ElectricPotentialChangeRate):
            raise TypeError("unsupported operand type(s) for >: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ElectricPotentialChangeRate):
            raise TypeError("unsupported operand type(s) for <=: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ElectricPotentialChangeRate):
            raise TypeError("unsupported operand type(s) for >=: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ElectricCurrentUnits(Enum):
        """
            ElectricCurrentUnits enumeration
        """
        
        Ampere = 'ampere'
        """
            
        """
        
        Femtoampere = 'femtoampere'
        """
            
        """
        
        Picoampere = 'picoampere'
        """
            
        """
        
        Nanoampere = 'nanoampere'
        """
            
        """
        
        Microampere = 'microampere'
        """
            
        """
        
        Milliampere = 'milliampere'
        """
            
        """
        
        Centiampere = 'centiampere'
        """
            
        """
        
        Kiloampere = 'kiloampere'
        """
            
        """
        
        Megaampere = 'megaampere'
        """
            
        """
        

class ElectricCurrent:
    """
    An electric current is a flow of electric charge. In electric circuits this charge is often carried by moving electrons in a wire. It can also be carried by ions in an electrolyte, or by both ions and electrons such as in a plasma.

    Args:
        value (float): The value.
        from_unit (ElectricCurrentUnits): The ElectricCurrent unit to create from, The default unit is Ampere
    """
    def __init__(self, value: float, from_unit: ElectricCurrentUnits = ElectricCurrentUnits.Ampere):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__amperes = None
        
        self.__femtoamperes = None
        
        self.__picoamperes = None
        
        self.__nanoamperes = None
        
        self.__microamperes = None
        
        self.__milliamperes = None
        
        self.__centiamperes = None
        
        self.__kiloamperes = None
        
        self.__megaamperes = None
        

    def __convert_from_base(self, from_unit: ElectricCurrentUnits) -> float:
        value = self.__value
        
        if from_unit == ElectricCurrentUnits.Ampere:
            return (value)
        
        if from_unit == ElectricCurrentUnits.Femtoampere:
            return ((value) / 1e-15)
        
        if from_unit == ElectricCurrentUnits.Picoampere:
            return ((value) / 1e-12)
        
        if from_unit == ElectricCurrentUnits.Nanoampere:
            return ((value) / 1e-09)
        
        if from_unit == ElectricCurrentUnits.Microampere:
            return ((value) / 1e-06)
        
        if from_unit == ElectricCurrentUnits.Milliampere:
            return ((value) / 0.001)
        
        if from_unit == ElectricCurrentUnits.Centiampere:
            return ((value) / 0.01)
        
        if from_unit == ElectricCurrentUnits.Kiloampere:
            return ((value) / 1000.0)
        
        if from_unit == ElectricCurrentUnits.Megaampere:
            return ((value) / 1000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricCurrentUnits) -> float:
        
        if to_unit == ElectricCurrentUnits.Ampere:
            return (value)
        
        if to_unit == ElectricCurrentUnits.Femtoampere:
            return ((value) * 1e-15)
        
        if to_unit == ElectricCurrentUnits.Picoampere:
            return ((value) * 1e-12)
        
        if to_unit == ElectricCurrentUnits.Nanoampere:
            return ((value) * 1e-09)
        
        if to_unit == ElectricCurrentUnits.Microampere:
            return ((value) * 1e-06)
        
        if to_unit == ElectricCurrentUnits.Milliampere:
            return ((value) * 0.001)
        
        if to_unit == ElectricCurrentUnits.Centiampere:
            return ((value) * 0.01)
        
        if to_unit == ElectricCurrentUnits.Kiloampere:
            return ((value) * 1000.0)
        
        if to_unit == ElectricCurrentUnits.Megaampere:
            return ((value) * 1000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_amperes(amperes: float):
        """
        Create a new instance of ElectricCurrent from a value in amperes.

        

        :param meters: The ElectricCurrent value in amperes.
        :type amperes: float
        :return: A new instance of ElectricCurrent.
        :rtype: ElectricCurrent
        """
        return ElectricCurrent(amperes, ElectricCurrentUnits.Ampere)

    
    @staticmethod
    def from_femtoamperes(femtoamperes: float):
        """
        Create a new instance of ElectricCurrent from a value in femtoamperes.

        

        :param meters: The ElectricCurrent value in femtoamperes.
        :type femtoamperes: float
        :return: A new instance of ElectricCurrent.
        :rtype: ElectricCurrent
        """
        return ElectricCurrent(femtoamperes, ElectricCurrentUnits.Femtoampere)

    
    @staticmethod
    def from_picoamperes(picoamperes: float):
        """
        Create a new instance of ElectricCurrent from a value in picoamperes.

        

        :param meters: The ElectricCurrent value in picoamperes.
        :type picoamperes: float
        :return: A new instance of ElectricCurrent.
        :rtype: ElectricCurrent
        """
        return ElectricCurrent(picoamperes, ElectricCurrentUnits.Picoampere)

    
    @staticmethod
    def from_nanoamperes(nanoamperes: float):
        """
        Create a new instance of ElectricCurrent from a value in nanoamperes.

        

        :param meters: The ElectricCurrent value in nanoamperes.
        :type nanoamperes: float
        :return: A new instance of ElectricCurrent.
        :rtype: ElectricCurrent
        """
        return ElectricCurrent(nanoamperes, ElectricCurrentUnits.Nanoampere)

    
    @staticmethod
    def from_microamperes(microamperes: float):
        """
        Create a new instance of ElectricCurrent from a value in microamperes.

        

        :param meters: The ElectricCurrent value in microamperes.
        :type microamperes: float
        :return: A new instance of ElectricCurrent.
        :rtype: ElectricCurrent
        """
        return ElectricCurrent(microamperes, ElectricCurrentUnits.Microampere)

    
    @staticmethod
    def from_milliamperes(milliamperes: float):
        """
        Create a new instance of ElectricCurrent from a value in milliamperes.

        

        :param meters: The ElectricCurrent value in milliamperes.
        :type milliamperes: float
        :return: A new instance of ElectricCurrent.
        :rtype: ElectricCurrent
        """
        return ElectricCurrent(milliamperes, ElectricCurrentUnits.Milliampere)

    
    @staticmethod
    def from_centiamperes(centiamperes: float):
        """
        Create a new instance of ElectricCurrent from a value in centiamperes.

        

        :param meters: The ElectricCurrent value in centiamperes.
        :type centiamperes: float
        :return: A new instance of ElectricCurrent.
        :rtype: ElectricCurrent
        """
        return ElectricCurrent(centiamperes, ElectricCurrentUnits.Centiampere)

    
    @staticmethod
    def from_kiloamperes(kiloamperes: float):
        """
        Create a new instance of ElectricCurrent from a value in kiloamperes.

        

        :param meters: The ElectricCurrent value in kiloamperes.
        :type kiloamperes: float
        :return: A new instance of ElectricCurrent.
        :rtype: ElectricCurrent
        """
        return ElectricCurrent(kiloamperes, ElectricCurrentUnits.Kiloampere)

    
    @staticmethod
    def from_megaamperes(megaamperes: float):
        """
        Create a new instance of ElectricCurrent from a value in megaamperes.

        

        :param meters: The ElectricCurrent value in megaamperes.
        :type megaamperes: float
        :return: A new instance of ElectricCurrent.
        :rtype: ElectricCurrent
        """
        return ElectricCurrent(megaamperes, ElectricCurrentUnits.Megaampere)

    
    @property
    def amperes(self) -> float:
        """
        
        """
        if self.__amperes != None:
            return self.__amperes
        self.__amperes = self.__convert_from_base(ElectricCurrentUnits.Ampere)
        return self.__amperes

    
    @property
    def femtoamperes(self) -> float:
        """
        
        """
        if self.__femtoamperes != None:
            return self.__femtoamperes
        self.__femtoamperes = self.__convert_from_base(ElectricCurrentUnits.Femtoampere)
        return self.__femtoamperes

    
    @property
    def picoamperes(self) -> float:
        """
        
        """
        if self.__picoamperes != None:
            return self.__picoamperes
        self.__picoamperes = self.__convert_from_base(ElectricCurrentUnits.Picoampere)
        return self.__picoamperes

    
    @property
    def nanoamperes(self) -> float:
        """
        
        """
        if self.__nanoamperes != None:
            return self.__nanoamperes
        self.__nanoamperes = self.__convert_from_base(ElectricCurrentUnits.Nanoampere)
        return self.__nanoamperes

    
    @property
    def microamperes(self) -> float:
        """
        
        """
        if self.__microamperes != None:
            return self.__microamperes
        self.__microamperes = self.__convert_from_base(ElectricCurrentUnits.Microampere)
        return self.__microamperes

    
    @property
    def milliamperes(self) -> float:
        """
        
        """
        if self.__milliamperes != None:
            return self.__milliamperes
        self.__milliamperes = self.__convert_from_base(ElectricCurrentUnits.Milliampere)
        return self.__milliamperes

    
    @property
    def centiamperes(self) -> float:
        """
        
        """
        if self.__centiamperes != None:
            return self.__centiamperes
        self.__centiamperes = self.__convert_from_base(ElectricCurrentUnits.Centiampere)
        return self.__centiamperes

    
    @property
    def kiloamperes(self) -> float:
        """
        
        """
        if self.__kiloamperes != None:
            return self.__kiloamperes
        self.__kiloamperes = self.__convert_from_base(ElectricCurrentUnits.Kiloampere)
        return self.__kiloamperes

    
    @property
    def megaamperes(self) -> float:
        """
        
        """
        if self.__megaamperes != None:
            return self.__megaamperes
        self.__megaamperes = self.__convert_from_base(ElectricCurrentUnits.Megaampere)
        return self.__megaamperes

    
    def to_string(self, unit: ElectricCurrentUnits = ElectricCurrentUnits.Ampere) -> string:
        """
        Format the ElectricCurrent to string.
        Note! the default format for ElectricCurrent is Ampere.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ElectricCurrentUnits.Ampere:
            return f"""{self.amperes} A"""
        
        if unit == ElectricCurrentUnits.Femtoampere:
            return f"""{self.femtoamperes} """
        
        if unit == ElectricCurrentUnits.Picoampere:
            return f"""{self.picoamperes} """
        
        if unit == ElectricCurrentUnits.Nanoampere:
            return f"""{self.nanoamperes} """
        
        if unit == ElectricCurrentUnits.Microampere:
            return f"""{self.microamperes} """
        
        if unit == ElectricCurrentUnits.Milliampere:
            return f"""{self.milliamperes} """
        
        if unit == ElectricCurrentUnits.Centiampere:
            return f"""{self.centiamperes} """
        
        if unit == ElectricCurrentUnits.Kiloampere:
            return f"""{self.kiloamperes} """
        
        if unit == ElectricCurrentUnits.Megaampere:
            return f"""{self.megaamperes} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricCurrentUnits = ElectricCurrentUnits.Ampere) -> string:
        """
        Get ElectricCurrent unit abbreviation.
        Note! the default abbreviation for ElectricCurrent is Ampere.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricCurrentUnits.Ampere:
            return """A"""
        
        if unit_abbreviation == ElectricCurrentUnits.Femtoampere:
            return """"""
        
        if unit_abbreviation == ElectricCurrentUnits.Picoampere:
            return """"""
        
        if unit_abbreviation == ElectricCurrentUnits.Nanoampere:
            return """"""
        
        if unit_abbreviation == ElectricCurrentUnits.Microampere:
            return """"""
        
        if unit_abbreviation == ElectricCurrentUnits.Milliampere:
            return """"""
        
        if unit_abbreviation == ElectricCurrentUnits.Centiampere:
            return """"""
        
        if unit_abbreviation == ElectricCurrentUnits.Kiloampere:
            return """"""
        
        if unit_abbreviation == ElectricCurrentUnits.Megaampere:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ElectricCurrent):
            raise TypeError("unsupported operand type(s) for +: 'ElectricCurrent' and '{}'".format(type(other).__name__))
        return ElectricCurrent(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ElectricCurrent):
            raise TypeError("unsupported operand type(s) for *: 'ElectricCurrent' and '{}'".format(type(other).__name__))
        return ElectricCurrent(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ElectricCurrent):
            raise TypeError("unsupported operand type(s) for -: 'ElectricCurrent' and '{}'".format(type(other).__name__))
        return ElectricCurrent(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ElectricCurrent):
            raise TypeError("unsupported operand type(s) for /: 'ElectricCurrent' and '{}'".format(type(other).__name__))
        return ElectricCurrent(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ElectricCurrent):
            raise TypeError("unsupported operand type(s) for %: 'ElectricCurrent' and '{}'".format(type(other).__name__))
        return ElectricCurrent(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ElectricCurrent):
            raise TypeError("unsupported operand type(s) for **: 'ElectricCurrent' and '{}'".format(type(other).__name__))
        return ElectricCurrent(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ElectricCurrent):
            raise TypeError("unsupported operand type(s) for ==: 'ElectricCurrent' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ElectricCurrent):
            raise TypeError("unsupported operand type(s) for <: 'ElectricCurrent' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ElectricCurrent):
            raise TypeError("unsupported operand type(s) for >: 'ElectricCurrent' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ElectricCurrent):
            raise TypeError("unsupported operand type(s) for <=: 'ElectricCurrent' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ElectricCurrent):
            raise TypeError("unsupported operand type(s) for >=: 'ElectricCurrent' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value